#==============================================================================
#	Fit Model in Stan
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
library(tidyverse)				#Data processing tools
suppressMessages(library(rstan))
#==============================================================================

#====Read Input Data===========================================================

if(file.exists('stan_input.Rdata')){
	load('stan_input.Rdata')
} else {
	load('../clean/stan_input.Rdata')
}
#==============================================================================

#====Select Final Species/Years================================================

#Remove incidental caps for smams caught in Shermans
st_trap_species = smam_codes$Code[smam_codes$Incidental == 0]
stan_input = stan_input %>%
  mutate(Incidental = ifelse(is.na(Incidental),3,Incidental)) %>%
  filter(! (Incidental == 1 & Species %in% st_trap_species) ) %>%
  filter(! (Incidental == 0 & ! Species %in% st_trap_species) )

species_keep = stan_input %>%
	group_by(Species) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(TotalCount >= 30 & TotalSites >= 20) %>%
	pull(Species)

#Subset to species_keep and create species index codes
stan_input = stan_input %>%
  filter(Species %in% species_keep & !is.na(Effort)) %>%
  mutate(Species = factor(Species, levels=species_keep),
         SpeciesCode = as.numeric(Species))
#==============================================================================

#====Final Stan Inputs=========================================================
dat = list(
	#Indices
	n_obs = nrow(stan_input),
	n_species = max(stan_input$SpeciesCode),
	n_sites = max(stan_input$Site),
	species = stan_input$SpeciesCode,
	site = stan_input$Site,

	#Response variable
	counts = stan_input$n,

	#Covariates
  X = stan_input %>%
		mutate(Int = 1) %>%
		mutate(Aft_un = After06 * Treatuneven,
		   Aft_ev = After06 * Treateven,
       Aft_un11 = After11 * Treatuneven,
       Aft_ev11 = After11 * Treateven,
       Regen = (After06*H06regen)|(After11*H11regen),
       Thin = (After06*H06thin)|(After11*H11thin),
       Singletree = (After06*H06singletree)|(After11*H11singletree)) %>%
		select(Int, After06, After11, Treatuneven, Treateven,
           Aft_un, Aft_ev, Aft_un11, Aft_ev11,
           Regen, Thin, Singletree) %>%
		as.matrix(),
	
  effort = log(stan_input$Effort) #Offset

)
dat$n_params = ncol(dat$X)

model_file = 'model_code.stan'
#==============================================================================

#====Run Stan==================================================================
rstan_options(auto_write = TRUE)
options(mc.cores = parallel::detectCores())

mofep_out = stan(model_code = readChar(model_file, file.info(model_file)$size),
			data = dat, 
			pars = c('beta','beta_mean','beta_sd','site_sd','obs_sd','yrep'),
			chains = 3, iter = 600, warmup = 500, thin = 1)

raw_counts = dat$counts
save(mofep_out, raw_counts,
     file=paste('model_fit_',format(Sys.time(),'%y-%m-%d_%H'),'.Rdata',sep=''))
#==============================================================================
