#==============================================================================
#	Fit Model in Stan
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
library(tidyverse)				#Data processing tools
suppressMessages(library(readxl))
suppressMessages(library(rstan))
#==============================================================================

#====Read Input Data===========================================================

if(file.exists('stan_input.Rdata')){
	load('stan_input.Rdata')
  herp_groups = read_excel(
    'MOFEP_Herps_1992_2014 combined_finalized.xlsx',
    sheet='SpeciesCode') %>%
    select(Species,Group)
} else {
	load('../clean/stan_input.Rdata')
  herp_groups = read_excel(
    '../data/herps/MOFEP_Herps_1992_2014 combined_finalized.xlsx',
    sheet='SpeciesCode') %>%
    select(Species,Group)
}
#==============================================================================

#====Select Final Species/Years================================================

#Remove sherman trap data
st_trap_species = smam_codes$Code[smam_codes$Incidental == 0]
stan_input = stan_input %>%
  mutate(Incidental = ifelse(is.na(Incidental),3,Incidental)) %>%
  filter(! (Incidental == 1 & Species %in% st_trap_species) ) %>%
  filter(! (Incidental == 0 & ! Species %in% st_trap_species) )



stan_input = stan_input %>%
  left_join(herp_groups, by='Species') %>% 
  mutate(TaxaEx = case_when(Group == 'Amphibian' ~ 'amphib',
                            Group == 'Reptile' ~ 'rept',
                            TRUE ~ Taxa))

rich_all = stan_input %>%
  filter(n>0) %>%
  group_by(Year, Stand, Site, Effort, TaxaEx, Treateven,Treatuneven,
           H06regen,H06thin,H06singletree,H11regen,
           H11thin,H11singletree,After06,After11,Since06,Since11) %>%
  summarize(Richness = sum(n>0)) %>%
  select(Year, Stand, Site, TaxaEx, Richness, Effort, everything()) %>%
  ungroup()

#====Final Stan Inputs=========================================================

gen_dat = function(taxa){
  
  rich_sub = rich_all %>%
    filter(TaxaEx == taxa, !is.na(Effort))

  dat = list(
	  #Indices
	  n_obs = nrow(rich_sub),
	  n_sites = max(rich_sub$Site),
	  site = rich_sub$Site,

	  #Response variable
	  richness = rich_sub$Richness,

	  #Covariates
	  X = rich_sub %>%
		  mutate(Int = 1) %>%
		  mutate(Aft_un = After06 * Treatuneven,
		    Aft_ev = After06 * Treateven,
        Aft_un11 = After11 * Treatuneven,
        Aft_ev11 = After11 * Treateven,
        Regen = (After06*H06regen)|(After11*H11regen),
        Thin = (After06*H06thin)|(After11*H11thin),
        Singletree = (After06*H06singletree)|(After11*H11singletree)) %>%
		  select(Int, After06, After11, Treatuneven, Treateven,
            Aft_un, Aft_ev, Aft_un11, Aft_ev11,
            Regen, Thin, Singletree) %>%
		  as.matrix(),
	  effort = log(rich_sub$Effort) #Offset
    )
  dat$n_params = ncol(dat$X)

  return(dat)
}

dat_bird = gen_dat('bird')
dat_smam = gen_dat('smam')
dat_amphib = gen_dat('amphib')
dat_rept = gen_dat('rept')

model_file = 'model_richness_code.stan'
#==============================================================================

#====Run Stan==================================================================
rstan_options(auto_write = TRUE)
options(mc.cores = parallel::detectCores())

rich_birds_out = stan(
      model_code = readChar(model_file, file.info(model_file)$size),
			data = dat_bird, 
			pars = c('beta','site_sd','obs_sd'),
			chains = 3, iter = 1000, warmup = 900, thin = 1)

rich_smam_out = stan(
      model_code = readChar(model_file, file.info(model_file)$size),
			data = dat_smam, 
			pars = c('beta','site_sd','obs_sd'),
			chains = 3, iter = 1000, warmup = 900, thin = 1)

rich_amphib_out = stan(
      model_code = readChar(model_file, file.info(model_file)$size),
			data = dat_amphib, 
			pars = c('beta','site_sd','obs_sd'),
			chains = 3, iter = 1000, warmup = 900, thin = 1)

rich_rept_out = stan(
      model_code = readChar(model_file, file.info(model_file)$size),
			data = dat_rept, 
			pars = c('beta','site_sd','obs_sd'),
			chains = 3, iter = 1000, warmup = 900, thin = 1)

save(rich_birds_out,rich_smam_out,rich_amphib_out, rich_rept_out,
      file=paste('model_richness_fit_',format(Sys.time(),'%y-%m-%d_%H'),
						  '.Rdata',sep=''))
#==============================================================================
