#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
library(tidyverse)				#Data processing tools
suppressMessages(library(rstan))
#==============================================================================

#====Read Input Data===========================================================

load('../clean/stan_input.Rdata')

#==============================================================================

#====Select Final Species/Years================================================

#Remove incidental caps for smams caught in Shermans
st_trap_species = smam_codes$Code[smam_codes$Incidental == 0]
stan_input = stan_input %>%
  mutate(Incidental = ifelse(is.na(Incidental),3,Incidental)) %>%
  filter(! (Incidental == 1 & Species %in% st_trap_species) ) %>%
  filter(! (Incidental == 0 & ! Species %in% st_trap_species) )

species_keep = stan_input %>%
	group_by(Species) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(TotalCount >= 30 & TotalSites >= 20) %>%
	pull(Species)

#Subset to species_keep and create species index codes
stan_input = stan_input %>%
  filter(Species %in% species_keep & !is.na(Effort)) %>%
  mutate(Species = factor(Species, levels=species_keep),
         SpeciesCode = as.numeric(Species))

species_info = stan_input %>%
	group_by(Species,Taxa) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(Species %in% species_keep)

#====Read Output Data==========================================================

#Most recent Rdata file
load(rev(list.files(pattern='model_fit_'))[1])
#==============================================================================

#====Extract Posteriors========================================================

betavals = extract(mofep_out, 'beta')$beta

betavals = betavals[,,species_info$Species != 'EUSK']
species_info = species_info %>% filter(Species != 'EUSK')

betameans = apply(betavals,c(2,3),mean)
betaup = apply(betavals,c(2,3),quantile,0.975)
betalow = apply(betavals,c(2,3),quantile,0.025)

#==============================================================================

#Function to generate posterior of derived param (combined site/stand effect)
#And calculate 95% CI
fun = function(x,cols,q){
  lims1 = quantile(x[,cols[1]],c(0.025,0.975))
  lims2 = quantile(x[,cols[2]],c(0.025,0.975))
  test1 = as.numeric(all(lims1>0|all(lims1<0))) 
  test2 = as.numeric(all(lims2>0|all(lims2<0)))

  comb = test1*x[,cols[1]] + test2*x[,cols[2]]

  quantile(comb,q)

}

upq = 0.975 ; lowq = 0.025

#Calculate values and add extra special rows for stacked barplot
species_info_out = species_info %>%
  left_join(rbind(herp_codes,bird_codes,smam_codes %>% select(Code,Species)) %>% 
            rename(Sci_name = Species, Species = Code),
            by="Species") %>%
  ungroup() %>%
	mutate(unev = betameans[6,],
		   unev_low = betalow[6,],
		   unev_up = betaup[6,],
		   unev_sig = as.logical(ifelse(((unev_low < 0 & unev_up < 0) | 
							 (unev_low > 0 & unev_up > 0)),1,0)),
		   ev = betameans[7,],
		   ev_low = betalow[7,],
		   ev_up = betaup[7,],
		   ev_sig = as.logical(ifelse(((ev_low < 0 & ev_up < 0) | 
							 (ev_low > 0 & ev_up > 0)),1,0)),
	     unev11 = betameans[8,],
		   unev11_low = betalow[8,],
		   unev11_up = betaup[8,],
		   unev11_sig = as.logical(ifelse(((unev11_low < 0 & unev11_up < 0) | 
							 (unev11_low > 0 & unev11_up > 0)),1,0)),
		   ev11 = betameans[9,],
		   ev11_low = betalow[9,],
		   ev11_up = betaup[9,],
		   ev11_sig = as.logical(ifelse(((ev11_low < 0 & ev11_up < 0) | 
							 (ev11_low > 0 & ev11_up > 0)),1,0))) %>%
	mutate(clear = betameans[10,],
		   clear_low = betalow[10,],
       clear_comblow = apply(betavals,3,fun,c(7,10),lowq),
       clear_combup = apply(betavals,3,fun,c(7,10),upq),
		   clear_up = betaup[10,],
		   clear_sig = as.logical(ifelse(((clear_low < 0 & clear_up < 0) | 
							 (clear_low > 0 & clear_up > 0)),1,0)),  
	     partial = betameans[11,],
       partial_comblow = apply(betavals,3,fun,c(7,11),lowq),
       partial_combup = apply(betavals,3,fun,c(7,11),upq),
		   partial_low = betalow[11,],
		   partial_up = betaup[11,],
		   partial_sig = as.logical(ifelse(((partial_low < 0 & partial_up < 0) | 
							 (partial_low > 0 & partial_up > 0)),1,0)),
	     singletree = betameans[12,],
       singletree_comblow = apply(betavals,3,fun,c(6,12),lowq),
       singletree_combup = apply(betavals,3,fun,c(6,12),upq),
		   singletree_low = betalow[12,],
		   singletree_up = betaup[12,],
		   singletree_sig = as.logical(ifelse(((singletree_low < 0 & 
                                            singletree_up < 0) | 
							 (singletree_low > 0 & singletree_up > 0)),1,0)))

options(warn=-1)
model_summary = species_info_out

save(model_summary,file='model_summary.Rdata')
