#==============================================================================
#	Effect Size x Species Figures
#==============================================================================

args = commandArgs(trailingOnly = TRUE)

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
library(tidyverse)				#Data processing tools
suppressMessages(library(rstan))
library(ggplot2)
#==============================================================================

#====Read Input Data===========================================================

load('../clean/stan_input.Rdata')

rev_sp = read_csv('../data/species.csv') %>%
  select(Code,Species) %>%
  rename(`Revised Species` = Species) %>%
  rename(Species = Code)

#==============================================================================

#====Select Final Species/Years================================================

#Remove incidental caps for smams caught in Shermans
st_trap_species = smam_codes$Code[smam_codes$Incidental == 0]
stan_input = stan_input %>%
  mutate(Incidental = ifelse(is.na(Incidental),3,Incidental)) %>%
  filter(! (Incidental == 1 & Species %in% st_trap_species) ) %>%
  filter(! (Incidental == 0 & ! Species %in% st_trap_species) )

species_keep = stan_input %>%
	group_by(Species) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(TotalCount >= 30 & TotalSites >= 20) %>%
	pull(Species)

#Subset to species_keep and create species index codes
stan_input = stan_input %>%
  filter(Species %in% species_keep & !is.na(Effort)) %>%
  mutate(Species = factor(Species, levels=species_keep),
         SpeciesCode = as.numeric(Species))

species_info = stan_input %>%
	group_by(Species,Taxa) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(Species %in% species_keep)

#====Read Output Data==========================================================

#Most recent Rdata file
load(paste('../analysis/',
           rev(list.files('../analysis',pattern='model_fit_'))[1],sep=''))

#==============================================================================

#====Extract Posteriors========================================================

betavals = extract(mofep_out, 'beta')$beta
betameans = apply(betavals,c(2,3),mean)
betaup = apply(betavals,c(2,3),quantile,0.975)
betalow = apply(betavals,c(2,3),quantile,0.025)

#==============================================================================

#====Reformat for Plots========================================================

options(warn=-1)
#Bind Species info with effect sizes
species_info_out = species_info %>%
	ungroup() %>%
	mutate(unev = betameans[6,],
		   unev_low = betalow[6,],
		   unev_up = betaup[6,],
		   unev_sig = as.logical(ifelse(((unev_low < 0 & unev_up < 0) | 
							 (unev_low > 0 & unev_up > 0)),1,0)),
		   ev = betameans[7,],
		   ev_low = betalow[7,],
		   ev_up = betaup[7,],
		   ev_sig = as.logical(ifelse(((ev_low < 0 & ev_up < 0) | 
							 (ev_low > 0 & ev_up > 0)),1,0)))

#Function to generate posterior of derived param (combined site/stand effect)
#And calculate 95% CI
fun = function(x,cols,q){
  lims1 = quantile(x[,cols[1]],c(0.025,0.975))
  lims2 = quantile(x[,cols[2]],c(0.025,0.975))
  test1 = as.numeric(all(lims1>0|all(lims1<0))) 
  test2 = as.numeric(all(lims2>0|all(lims2<0)))

  comb = test1*x[,cols[1]] + test2*x[,cols[2]]

  quantile(comb,q)

}

upq = 0.975 ; lowq = 0.025

#Calculate values and add extra special rows for stacked barplot
species_info_out = species_info %>%
	ungroup() %>%
	mutate(unev = betameans[6,],
		   unev_low = betalow[6,],
		   unev_up = betaup[6,],
		   unev_sig = as.logical(ifelse(((unev_low < 0 & unev_up < 0) | 
							 (unev_low > 0 & unev_up > 0)),1,0)),
		   ev = betameans[7,],
		   ev_low = betalow[7,],
		   ev_up = betaup[7,],
		   ev_sig = as.logical(ifelse(((ev_low < 0 & ev_up < 0) | 
							 (ev_low > 0 & ev_up > 0)),1,0))) %>%
	mutate(clear = betameans[10,],
		   clear_low = betalow[10,],
       clear_comblow = apply(betavals,3,fun,c(7,10),lowq),
       clear_combup = apply(betavals,3,fun,c(7,10),upq),
		   clear_up = betaup[10,],
		   clear_sig = as.logical(ifelse(((clear_low < 0 & clear_up < 0) | 
							 (clear_low > 0 & clear_up > 0)),1,0)),  
	     partial = betameans[11,],
       partial_comblow = apply(betavals,3,fun,c(7,11),lowq),
       partial_combup = apply(betavals,3,fun,c(7,11),upq),
		   partial_low = betalow[11,],
		   partial_up = betaup[11,],
		   partial_sig = as.logical(ifelse(((partial_low < 0 & partial_up < 0) | 
							 (partial_low > 0 & partial_up > 0)),1,0)),
	     singletree = betameans[12,],
       singletree_comblow = apply(betavals,3,fun,c(6,12),lowq),
       singletree_combup = apply(betavals,3,fun,c(6,12),upq),
		   singletree_low = betalow[12,],
		   singletree_up = betaup[12,],
		   singletree_sig = as.logical(ifelse(((singletree_low < 0 & singletree_up < 0) | 
							 (singletree_low > 0 & singletree_up > 0)),1,0)))

#Filter to only species with at least one significant effect
sig_species = species_info_out %>%
  filter(ev_sig|unev_sig|clear_sig|partial_sig|singletree_sig) %>%
  mutate(ev_clear=ev,ev_clear_low=ev_low,ev_clear_up=ev_up,
         ev_partial=ev,ev_partial_low=ev_low,ev_partial_up=ev_up,
         unev_single=unev,unev_single_low=unev_low,unev_single_up=unev_up) %>%
  select(-TotalCount,-TotalSites,-contains('sig'))

#Convert to "long" format for ggplot2
fig_data = sig_species %>%
  left_join(rbind(herp_codes,bird_codes,smam_codes %>% select(Code,Species)) %>% 
            rename(Sci_name = Species, Species = Code),
            by="Species") %>%
  select(-contains('_up'),-contains('_low')) %>%
  gather(key='var_tmp',value='effect',unev:unev_single) %>%
  left_join(sig_species %>% 
            select(Species,Taxa,contains('_low')) %>%
            gather(key='var_tmp',value='effect_low',contains('_low')) %>%
            mutate(var_tmp=str_replace(var_tmp,'_low','')), 
            by=c('Species','Taxa','var_tmp')) %>%
  left_join(sig_species %>% 
            select(Species,Taxa,contains('_up')) %>%
            gather(key='var_tmp',value='effect_up',contains('_up')) %>%
            mutate(var_tmp=str_replace(var_tmp,'_up','')), 
            by=c('Species','Taxa','var_tmp')) %>%
  left_join(sig_species %>% 
            select(Species,Taxa,contains('_comblow')) %>%
            gather(key='var_tmp',value='effect_comblow',contains('_comblow')) %>%
            mutate(var_tmp=str_replace(var_tmp,'_comblow','')),
            by=c('Species','Taxa','var_tmp')) %>%
  left_join(sig_species %>% 
            select(Species,Taxa,contains('_combup')) %>%
            gather(key='var_tmp',value='effect_combup',contains('_combup')) %>%
            mutate(var_tmp=str_replace(var_tmp,'_combup','')), 
            by=c('Species','Taxa','var_tmp')) %>%
  mutate(effect = ifelse(effect>0 & effect_low <0,0,effect),
         effect = ifelse(effect<0 & effect_up>0,0,effect),
         effect_low = ifelse(effect==0,0,effect_low),
         effect_up = ifelse(effect==0,0,effect_up))

fig_data = fig_data %>%
  left_join(rev_sp, by='Species') %>%
  mutate(Sci_name = ifelse(is.na(`Revised Species`),Sci_name,`Revised Species`)) %>%
  select(-`Revised Species`)

#Add another column so that bars stack properly
fig_adjust = fig_data %>%
  arrange(Species) %>%
  mutate(harvest=case_when(
                  var_tmp == 'ev' ~ 'EA-matrix',
                  var_tmp == 'unev' ~ 'UA-matrix',
                  var_tmp %in% c('clear','ev_clear') ~ 'EA-clearcut',
                  var_tmp %in% c('partial','ev_partial') ~ 'EA-thin',
                  var_tmp %in% c('unev_single','singletree') ~ 'UA-singletree')) %>%
  mutate(harvest = factor(harvest,levels=c('EA-matrix','EA-clearcut','EA-thin',
                                           'UA-matrix','UA-singletree'))) %>%
  filter(!is.na(harvest)) %>%
  mutate(`Effect Source` = ifelse(var_tmp %in% 
                            c('ev','unev','ev_clear','ev_partial','unev',
                              'unev_single'),
                            'Treatment (compartment)',
                            'Harvest (stand)'),
         effect_comblow = ifelse(is.na(effect_comblow) &
                                 var_tmp %in% c('ev','unev'),
                                 effect_low,
                                 effect_comblow),
         effect_combup = ifelse(is.na(effect_combup) &
                                var_tmp %in% c('ev','unev'),
                                effect_up,
                                effect_combup),
         effect_comblow = ifelse(effect_comblow != 0, effect_comblow, NA))

mean_pts = fig_adjust %>%
  group_by(harvest,Sci_name) %>%
  summarize(comb_eff = sum(effect))

fig_adjust = fig_adjust %>%
  left_join(mean_pts,by=c('harvest','Sci_name')) %>%
  mutate(comb_eff = ifelse(comb_eff==0,NA,comb_eff)) %>%
  filter(Species != 'EUSK')
#==============================================================================

#====Generate figures==========================================================

#General function for one taxa at a time
plot_response <- function(taxa,ncols){
  
  if(taxa == 'bird'){
    label_face="italic"
  } else { label_face = "italic"}

  out <- fig_adjust %>%
    filter(Taxa==taxa) %>%
    ggplot(aes(x=harvest,y=effect,fill=`Effect Source`)) +
    geom_bar(stat='identity',position='stack') +
    scale_fill_manual(values=c('firebrick2','dodgerblue'),
                      name='Effect Source') +
    geom_hline(aes(yintercept=0),color='white',size=1.2) +
    geom_vline(aes(xintercept=3.5),linetype='longdash') +
    facet_wrap(~ Sci_name, drop=TRUE,ncol=ncols) +
    labs(y = "log(Total effect size)") +
    theme(axis.title.x=element_blank(),
        axis.text.x = element_text(angle = 90, hjust = 1),
        legend.position='bottom',
        strip.text = element_text(face = label_face,size=10)) +
    geom_point(aes(x=harvest,y=comb_eff),color='black',size=0.7,
               show_guide=FALSE) +
    geom_errorbar(aes(ymin=effect_comblow,ymax=effect_combup),width=0.1)

  if(taxa=='smam'){
    out <- out + ylim(c(-0.5,2))
  }
  out
}

#Generate figures
#plot_response('bird')
#ggsave('fig_bird.pdf',width=10)

#plot_response('smam')
#ggsave('fig_smams.pdf',height=4)

#plot_response('herp')
#ggsave('fig_herp.pdf',width=10)

#plot_response(args[1],args[4])
#ggsave(paste('fig_appendixD_',args[1],'.pdf',sep=''),
#       height=as.numeric(args[2]), width=as.numeric(args[3]))
#ggsave(paste('fig_appendix1_',args[1],'.tiff',sep=''),
#       height=as.numeric(args[2]), width=as.numeric(args[3]),
#       dpi=300,compression='lzw')
options(warn=0)
