#==============================================================================
#	Script to Clean MOFEP Birds Data
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
options(dplyr.show_progress=FALSE)
library(tidyverse)				#Data processing tools
suppressMessages(library(sf))	#Spatial data tools
library(readxl)					#Read Excel spreadsheets
#==============================================================================

#====Read Possible Bird Codes==================================================

codesxl = '../data/birds/BirdSpeciesCodes.xls'

bird_codes = read_excel(codesxl) %>% arrange(Code)
sp_codes = bird_codes$Code
#==============================================================================

#====Load Spatial Data=========================================================
options(warn=-1)

#MOFEP geodatabase
mofep_db = '../data/MOFEP.gdb'

#Define stand boundaries
stand_area = st_read(mofep_db,layer='STAND_BOUNDARY',quiet=T) %>%
	unite(Stand,SITE_ID,STAND_ID) %>%
	mutate(Area = Shape_Area / 10000) %>%
	select(Stand,Area) %>%
	distinct(Stand,.keep_all=TRUE) %>%
	arrange(Stand)

plot_bounds = st_read(mofep_db,layer='BIRD_SUB_PLOTS')

split_stands = stand_area %>% st_intersection(plot_bounds) %>%
  mutate(sep_area = st_area(.),
         sep_area = as.numeric(sep_area)/10000) %>%
  group_by(Stand) %>%
  summarize(AreaClip = sum(sep_area)) %>%
  st_set_geometry(NULL)

#oneyear = read_excel(birds_dat2010,sheet='DATA') %>% filter(YEAR==2008)
#table(oneyear$SITE_NO,oneyear$PLOT_NO)

plot_bounds_sub = st_read(mofep_db,layer='BIRD_SUB_PLOTS') %>%
  mutate(keep_subplot = case_when(SITE_ID==1&SUBPLOT_ID%in%c(1:4) ~ TRUE,
                                  SITE_ID==2&SUBPLOT_ID%in%c(4:7) ~ TRUE,
                                  SITE_ID==3&SUBPLOT_ID%in%c(2,4,6,7) ~ TRUE,
                                  SITE_ID==4&SUBPLOT_ID%in%c(1:3,5) ~ TRUE,
                                  SITE_ID==5&SUBPLOT_ID%in%c(1:3,5) ~ TRUE,
                                  SITE_ID==6&SUBPLOT_ID%in%c(1:4) ~ TRUE,
                                  SITE_ID==7&SUBPLOT_ID%in%c(1:4) ~ TRUE,
                                  SITE_ID==8&SUBPLOT_ID%in%c(2,3,6,7) ~ TRUE,
                                  SITE_ID==9&SUBPLOT_ID%in%c(1,2,4,5) ~ TRUE,
                                  TRUE ~ FALSE)) %>%
  filter(keep_subplot)

split_stands_sub = stand_area %>% st_intersection(plot_bounds_sub) %>%
  mutate(sep_area = st_area(.),
         sep_area = as.numeric(sep_area)/10000) %>%
  group_by(Stand) %>%
  summarize(AreaClipSub = sum(sep_area)) %>%
  st_set_geometry(NULL)

stand_area = stand_area %>% 
  left_join(split_stands,by='Stand') %>%
  left_join(split_stands_sub,by='Stand')

new_stand_area = stand_area %>%
  st_set_geometry(NULL) %>%
  select(-Area) %>%
  rename(RegYear = AreaClip, SubYear = AreaClipSub) %>%
  gather(key='YearType',value='Area',RegYear,SubYear)
#==============================================================================

#====Read Territory Datafiles==================================================

birds_dat2010 = '../data/birds/Bird_Terr_1991_2010_by_STAND.xlsx'
birds_dat2014 = '../data/birds/TERRITORIES_2012_2014.shp'

bird_ter_2010 = read_excel(birds_dat2010,sheet='DATA') %>%
	filter(STANDNO != 0 & !is.na(STANDNO)) %>%
	unite(Stand,SITE_NO,STANDNO) %>%
	select(YEAR,Stand,SPECIES) %>%
  filter(!YEAR%in%c(2004:2007))

bird_ter = st_read(birds_dat2014,quiet=T) %>%
  st_intersection(stand_area) %>%
  st_set_geometry(NULL) %>%
  as_tibble() %>%
  select(YEAR,Stand,SPECIES) %>%
  rbind(bird_ter_2010) %>%
  rename(Year = YEAR, Species = SPECIES) %>%
	mutate(Species = str_to_upper(Species)) %>%
	filter(Species%in%sp_codes) %>%
	mutate(Species = factor(Species,levels=sort(unique(Species))))

options(warn=0)
#==============================================================================

#====Summarize Territories=====================================================

birds_clean = bird_ter %>%
	group_by(Year,Stand,Species) %>%
	summarize(n = n()) %>%
	complete(Species, fill=list(n=0L)) %>%
  mutate(YearType=ifelse(Year%in%c(2001:2003,2008:2010),'SubYear','RegYear')) %>%
	left_join(new_stand_area, by=c('Stand','YearType')) %>%
	ungroup() %>%
	mutate(Stand = as.character(Stand),
	Species = as.character(Species)) %>%
	select(Year,Stand,Species,n,Area) %>%
  filter(!is.na(Area))

save(birds_clean,bird_codes,file='clean_bird_data.Rdata')
#==============================================================================
