#==============================================================================
#	Script to Clean MOFEP Herps Data
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
suppressMessages(library(sf))			#Spatial data tools
library(tidyverse)						#Data processing tools
suppressMessages(library(lubridate))	#Date-time processing tools
library(readxl)							#Read Excel spreadsheets
#==============================================================================

#====Load Spatial Data=========================================================
options(warn=-1)

#MOFEP geodatabase
mofep_db = '../data/MOFEP.gdb'

#Define stand boundaries
stands = st_read(mofep_db,layer='STAND_BOUNDARY',quiet=T) %>%
	unite(Stand,SITE_ID,STAND_ID)

#Herp grid locations
herp_grids = st_read(mofep_db,layer='HERPTILE_PLOTS',quiet=T) %>%
	mutate(GridID = SITE_ID * 100 + ARRAY_ID) %>%
	st_intersection(stands)

options(warn=0)
#==============================================================================

#====Read Herp Datafiles=======================================================

#====Herp Species Codes========================================================
herpsxl = '../data/herps/MOFEP_Herps_1992_2014 combined_finalized.xlsx'

#Possible species codes
herp_meta = read_excel(herpsxl,sheet='SpeciesCode')
herp_codes = herp_meta %>%
	filter(!str_detect(Species,"\\?")) %>%
	filter(!Species%in%c('None','Unk')) %>%
	rename(Code = Species,
		   Species = `Species Name`) %>%
	select(Code, Species) %>%
	arrange(Code)
	
sp_codes = herp_codes$Code
#==============================================================================

#====Herp Effort===============================================================
#Effort is # of days checked

#Make sane column headers
effortxl = '../data/herps/Trap check dates.xlsx'
col_headers = read_excel(effortxl,sheet='Trap effort',n_max=2) %>%
	t() %>%
	as_tibble() %>%
	rownames_to_column() %>%
	mutate(Season = case_when(
			str_detect(V2,'Feb') ~ 'spring',
			str_detect(V2,'May') ~ 'summer',
			str_detect(V2,'Aug') ~ 'fall')) %>%
	unite(comb,V1,Season) %>%
	pull(comb)
col_headers[1] = 'GridID'

#Get effort by stand, year, and season
herp_effort = read_excel(effortxl,sheet='Trap effort',skip=2)
names(herp_effort) = col_headers
herp_effort = herp_effort %>%
	gather(season,Effort,2:ncol(.)) %>%
	separate(season,c('Year','Season')) %>%
	mutate(Season = factor(Season,levels=c('spring','summer','fall'))) %>%
	separate(GridID,c('Site','Array'),convert=TRUE) %>%
	mutate(GridID = Site * 100 + Array) %>%
	left_join(herp_grids,by="GridID") %>%
	mutate(Stand = factor(Stand)) %>%
	mutate(Year = factor(Year)) %>%
	group_by(Stand,Year,Season) %>%
	summarize(Effort = sum(Effort))
#==============================================================================

#====Compile Herp Captures=====================================================
herps_raw = read_excel(herpsxl,sheet='MOFEP_Herp_All_Years')

#Clean up species and time
herp_caps = herps_raw %>%
	rename(Species = SPECIES) %>%
	filter(Species%in%sp_codes) %>%
	mutate(Species = factor(Species, levels=sp_codes)) %>%
	mutate(Season = case_when(
			month(DATE) %in% c(2:4) ~ 'spring',
			month(DATE) %in% c(5:7) ~ 'summer',
			month(DATE) %in% c(8:11) ~ 'fall')) %>%
	mutate(Season = factor(Season,levels=c('spring','summer','fall'))) %>%
	mutate(Year = year(DATE))

#Clean up Grid ID
herp_caps = herp_caps %>%
	mutate(ARRAY = as.integer(ARRAY)) %>%
	filter(ARRAY!=0) %>%
	mutate(ARRAY = ifelse(
			ARRAY > 100,
			ARRAY - (ARRAY %/% 100 * 100),
			ARRAY)) %>%
	filter(ARRAY%in%c(1:12)) %>%
	mutate(`STUDY SITE` = as.integer(`STUDY SITE`)) %>%
	filter(`STUDY SITE` != 0) %>%
	mutate(GridID = `STUDY SITE` * 100 + ARRAY)

#Attach stand location to grids
herp_caps = herp_caps %>%
	left_join(herp_grids,by="GridID") %>%
	mutate(Stand = factor(Stand)) %>%
	arrange(Year,Season,Stand) %>%
	mutate(Year = factor(Year)) %>%
	select(Year,Season,Stand,Species)

#Summarize by year (pooling across seasons)
herp_sum = herp_caps %>%
	group_by(Stand,Year,Species) %>%
	summarize(n=n()) %>%
	complete(Species, fill=list(n=0L))

#Attach effort data
herp_effort_yr = herp_effort %>%
	summarize(Effort=as.integer(sum(Effort)))
	
herps_clean = herp_sum %>%
	left_join(herp_effort_yr,by=c('Stand','Year')) %>%
	ungroup() %>%
	mutate(Year = as.double(as.character(Year)),
		   Stand = as.character(Stand),
		   Species = as.character(Species)) %>%
	select(Year,Stand,Species,n,Effort)

save(herps_clean,herp_codes,file='clean_herp_data.Rdata')
