#==============================================================================
#	Script to Clean MOFEP Small Mammal Data
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
suppressMessages(library(sf))	#Spatial data tools
library(tidyverse)				#Data processing tools
library(foreign) 				#Import DBF files
source('read_mdb.R') 	#Import MDB files (requires mdbtools)
suppressMessages(library(lubridate))	#Date-time processing tools
library(readxl)							#Read Excel spreadsheets
#==============================================================================

#====Load Spatial Data=========================================================
options(warn=-1)

#MOFEP geodatabase
mofep_db = '../data/MOFEP.gdb'

#Define stand boundaries
stands = st_read(mofep_db,layer='STAND_BOUNDARY',quiet=T) %>%
	unite(Stand,SITE_ID,STAND_ID)

#Get stand each trap is in
sm_traps = st_read(mofep_db,layer='MAMMAL_TRAP_GRIDS_2011',quiet=T) %>%
	unite(TrapID, SITE_ID,Grid,Station) %>%
	arrange(TrapID) %>%
	st_intersection(stands) %>%	
	st_set_geometry(NULL) %>%
	rename(Trap_Stand = Stand) %>%
	select(TrapID,Trap_Stand) %>%
	as_tibble()

#List of stands containing traps
stand_codes = sort(unique(sm_traps$Trap_Stand))

#Get number of traps per stand
traps_per_stand = sm_traps %>%
	group_by(Trap_Stand) %>%
	summarize(Traps=n()) %>%
	rename(Stand = Trap_Stand) %>%
	mutate(Stand = factor(Stand,levels=stand_codes))

#Get stand each grid centroid is in
#Used if individual trap can't be matched to a stand
sm_stands = st_read(mofep_db,layer='MAMMAL_TRAP_GRID_CORNERS',quiet=T) %>%
	unite(GridID,SITE_ID,Grid) %>%
	group_by(GridID) %>%
	summarize() %>%
	st_centroid() %>%
	st_intersection(stands) %>%
	st_set_geometry(NULL) %>%
	rename(Grid_Stand = Stand) %>%
	select(c('GridID','Grid_Stand'))

#Herp grid locations
herp_grids = st_read(mofep_db,layer='HERPTILE_PLOTS',quiet=T) %>%
	mutate(GridID = SITE_ID * 100 + ARRAY_ID) %>%
	st_intersection(stands)

#==============================================================================

#====Function to clean data====================================================
read_smam = function(file){
	
	#Get year from filename
	year = as.numeric(str_extract(file, '\\d+')) 
	if (year<100&year>50) year = year+1900
	if (year<10) year = year+2000

	#Standardize columns between years
	#Generate Site-grid and Site-grid-trap identifiers
	#Newer datafiles have different column names
	if (year>2008){
		inp = read_mdb(file)
		if (!is_tibble(inp)) inp = inp[[1]]
		out = inp %>%
			filter(Species%in%sp_codes) %>%
			mutate(Species = factor(Species,levels=sp_codes)) %>%
			unite(GridID, `Study Site`,`Grid Number`, remove=FALSE) %>%
			unite(TrapID, `Study Site`, `Grid Number`, `Station Number`)
	} else { #Early years
		inp = as_tibble(read.dbf(file,as.is=TRUE))
		out = inp %>%
			filter(SPECIES%in%sp_codes) %>%
			mutate(Species = factor(SPECIES,levels=sp_codes)) %>%
			unite(GridID, SITE, GRID, remove=FALSE) %>%
			unite(TrapID, SITE, GRID, STATION)
	}
 
  #Collapse Peromyscus into one species
  new_sp = sort(c(sp_codes[!sp_codes%in%c('PELE','PEMA')],'PESP'))
  out = out %>%
    mutate(Species = recode(Species, 'PELE' = 'PESP'),
           Species = recode(Species, 'PEMA' = 'PESP'),
           Species = factor(Species, levels=new_sp))

	#Assign stands to each trap and grid
	out = out %>%	
		left_join(sm_stands,by='GridID') %>%
		left_join(sm_traps,by='TrapID') %>%
		mutate(Stand = coalesce(Trap_Stand,Grid_Stand)) %>%
		mutate(Stand = factor(Stand,levels=stand_codes))
	
	#Generate capture count for each species x stand combination
	#Also get effort (# traps) per stand and attach
	out = out %>%
		complete(Stand) %>%
		group_by(Stand,Species) %>%
		summarize(n = n()) %>%
		complete(Species,fill=list(n=0L)) %>%
		filter(!is.na(Species)) %>%
		mutate(Year = year) %>%
		left_join(traps_per_stand,by='Stand') %>%
		rename(Effort = Traps) %>%
		ungroup() %>%
		mutate(Stand = as.character(Stand),
			   Species = as.character(Species)) %>%
		select(Year,Stand,Species,n,Effort)
}
#==============================================================================

#====Process Datafiles=========================================================
curdir = getwd()
setwd('../data/small_mammals')

#List of possible species
smam_codes = read_mdb('MOFEPMammal2009.mdb')[[2]] %>%
	rename(Code = `Species Code`) %>%
	select(Code, Species) %>%
	arrange(Code)

sp_codes = smam_codes$Code

#Clean and combine data
data_files = c('MAMM94.DBF','MAMM95.DBF','MAMM98.DBF','MAMM99.DBF',
			   'MAMM00.DBF','MAMM01.DBF','MOFEPMammal2009.mdb',
			   'MOFEPMammal2010All.mdb','MOFEPmammal2012spring.mdb',
			   '"MOFEP Mammal 2013 - Spring final.mdb"',
			   'MOFEP_Small_Mammal_2014_compiled.mdb')

smams_clean = do.call(rbind, map(data_files, read_smam))

#Final species list with collapsed Peromyscus
smam_codes = smam_codes %>%
  filter(! Code %in% c('PELE','PEMA')) %>%
  rbind(list(Code='PESP',Species='Peromyscus spp.')) %>%
  arrange(Code)
 
setwd(curdir)

#====Process Incidental Capture Data===========================================

#====Species Codes=============================================================
inc_mam_xl = '../data/herps/MOFEP Incidental Mammal_1994_2014_combined.xlsx'

#Possible species codes
inc_mam_codes = read_excel(inc_mam_xl,sheet='SppCodes') %>%
	rename(Code = `Species Code`) %>%
  filter(! Code %in% c('PELE','PEMA')) %>%
  rbind(list(Code='PESP',Species='Peromyscus spp.')) %>%
  arrange(Code)

#==============================================================================

#====Herp Grid Effort==========================================================
#Effort is # of days checked

#Make sane column headers
effortxl = '../data/herps/Trap check dates.xlsx'
col_headers = read_excel(effortxl,sheet='Trap effort',n_max=2) %>%
	t() %>%
	as_tibble() %>%
	rownames_to_column() %>%
	mutate(Season = case_when(
			str_detect(V2,'Feb') ~ 'spring',
			str_detect(V2,'May') ~ 'summer',
			str_detect(V2,'Aug') ~ 'fall')) %>%
	unite(comb,V1,Season) %>%
	pull(comb)
col_headers[1] = 'GridID'

#Get effort by stand, year, and season
herp_effort = read_excel(effortxl,sheet='Trap effort',skip=2)
names(herp_effort) = col_headers
herp_effort = herp_effort %>%
	gather(season,Effort,2:ncol(.)) %>%
	separate(season,c('Year','Season')) %>%
	mutate(Season = factor(Season,levels=c('spring','summer','fall'))) %>%
	separate(GridID,c('Site','Array'),convert=TRUE) %>%
	mutate(GridID = Site * 100 + Array) %>%
	left_join(herp_grids,by="GridID") %>%
	mutate(Stand = factor(Stand)) %>%
	mutate(Year = factor(Year)) %>%
	group_by(Stand,Year,Season) %>%
	summarize(Effort = sum(Effort))
#==============================================================================

#====Compile Incidental Captures===============================================
inc_mam_raw = read_excel(inc_mam_xl,sheet='Incind_mammals_94_14')
options(warn=0)

#Clean up species and time
#Collapse Peromyscus into one species
inc_mam_caps = inc_mam_raw %>%
  mutate(Species = recode(Species, 'PELE' = 'PESP'),
         Species = recode(Species, 'PEMA' = 'PESP')) %>%
	filter(Species%in%inc_mam_codes$Code) %>%
	mutate(Species = factor(Species, levels=inc_mam_codes$Code)) %>%
	mutate(Year = year(Date))

#Clean up Grid ID
inc_mam_caps = inc_mam_caps %>%
	mutate(Array = as.integer(Array)) %>%
	filter(Array!=0) %>%
	mutate(Array = ifelse(
			Array > 100,
			Array - (Array %/% 100 * 100),
			Array)) %>%
	filter(Array%in%c(1:12)) %>%
	mutate(`Study Site` = as.integer(`Study Site`)) %>%
	filter(`Study Site` != 0) %>%
	mutate(GridID = `Study Site` * 100 + Array)

#Attach stand location to grids
inc_mam_caps = inc_mam_caps %>%
	left_join(herp_grids,by="GridID") %>%
	mutate(Stand = factor(Stand)) %>%
	arrange(Year,Stand) %>%
	mutate(Year = factor(Year)) %>%
	select(Year,Stand,Species)

#Summarize by year (pooling across seasons)
inc_mam_sum = inc_mam_caps %>%
	group_by(Stand,Year,Species) %>%
	summarize(n=n()) %>%
	complete(Species, fill=list(n=0L))

#Attach effort data
herp_effort_yr = herp_effort %>%
	summarize(Effort=as.integer(sum(Effort))) %>%
  ungroup() %>%
  mutate(Year = as.double(as.character(Year)),
         Stand = as.character(Stand))
	
inc_mam_clean = inc_mam_sum %>%
	ungroup() %>%
	mutate(Year = as.double(as.character(Year)),
		   Stand = as.character(Stand),
		   Species = as.character(Species)) %>%
	left_join(herp_effort_yr,by=c('Stand','Year')) %>%
	select(Year,Stand,Species,n,Effort) %>%
  mutate(Incidental = 1)

#====Combine Mammal Datasets===================================================

smams_clean = smams_clean %>%
  mutate(Incidental = 0) %>%
  rbind(inc_mam_clean) %>%
  arrange(Year,Stand,Species)

#Species more frequently captured by standard trapping
species_st_trap = c('NEFL','PESP','TAST')
smam_codes = smam_codes %>%
  mutate(Incidental = ifelse(Code %in% species_st_trap,0,1))

save(smams_clean,smam_codes,file='clean_smam_data.Rdata')

#==============================================================================
