#==============================================================================
#	MOFEP map in R
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
suppressMessages(library(sf))			#Spatial data tools
library(tidyverse)				#Data processing tools
suppressMessages(library(tigris))
suppressMessages(library(ggplot2))
suppressMessages(library(ggsn))
suppressMessages(library(cowplot))
#==============================================================================

#====USA and MO Maps===========================================================
options(warn=-1)
print('Downloading boundary data from TIGRIS')

usa = states(cb=TRUE,class='sf') %>%
  filter(! NAME %in% c('Alaska','Hawaii','Puerto Rico','American Samoa',
                       'Commonwealth of the Northern Mariana Islands',
                       'United States Virgin Islands','Guam')) %>%
  mutate(is_mo = ifelse(NAME=='Missouri',TRUE,FALSE)) %>%
  st_transform('+proj=aea +lat_1=29.5 +lat_2=45.5 +lat_0=37.5 
               +lon_0=-96 +x_0=0 +y_0=0 +ellps=GRS80 +datum=NAD83 
               +units=m +no_defs')


usa_map = usa %>% 
  ggplot() +
  geom_sf(aes(fill=is_mo)) +
  scale_fill_manual(values=c('white','gray')) +
  coord_sf(datum = NA) +
  theme_void() +
  theme(legend.position='none')

missouri = counties(class='sf',state=29, cb=TRUE) %>%
  st_transform('+proj=aea +lat_1=29.5 +lat_2=45.5 +lat_0=37.5 
               +lon_0=-96 +x_0=0 +y_0=0 +ellps=GRS80 +datum=NAD83 
               +units=m +no_defs') %>%
  mutate(is_mofep = 
         ifelse(NAME %in% c('Reynolds','Shannon','Carter'),TRUE,FALSE))

loc_counties = missouri %>%
  filter(is_mofep)

#mo_map = usa %>%
#  filter(NAME=='Missouri') %>%
#  ggplot() +
#  geom_sf(fill='white') +
#  geom_sf(data=loc_counties,fill='gray') +
#  coord_sf(datum = NA) +
#  theme_void() +
#  theme(legend.position='none')



#==============================================================================

#====MOFEP compartments map====================================================

#MOFEP geodatabase
mofep_db = '../data/MOFEP.gdb'

compartments = st_read(mofep_db,layer='SITE_BOUNDARY',quiet=T) %>%
  rename(geometry = Shape,
         Treatment = TREATMENT) %>%
  mutate(Treatment = fct_recode(Treatment, `No harvest` = 'NO HARVEST',
                                `Uneven-aged` = 'UNEVEN-AGED',
                                `Even-aged` = 'EVEN-AGED'),
         Treatment = factor(Treatment,levels=c('Even-aged','Uneven-aged',
                                               'No harvest'))) %>%
  st_transform(st_crs(missouri))

comp_box <- compartments %>%
  st_make_grid(n=1)

mo_map = usa %>%
  filter(NAME=='Missouri') %>%
  ggplot() +
  geom_sf(fill='white') +
  geom_sf(data=comp_box, fill='gray') +
  coord_sf(datum = NA) +
  theme_void() +
  theme(legend.position='none')

comp_coords = st_coordinates(compartments)

mofep_map = comp_box %>% ggplot() +
  geom_sf(color='gray') +
  geom_sf(data=compartments,aes(fill=Treatment)) + 
  scale_fill_manual(values=c('firebrick2','dodgerblue2','forestgreen')) +
  #scale_fill_manual(values=c('black','gray','white')) +
  coord_sf(xlim=range(comp_coords[,'X']),
           ylim=range(comp_coords[,'Y'])) +
  theme(axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x=element_text(size=9),
        axis.text.y=element_text(size=9),
        legend.position=c(0.05,0.6),
        legend.text=element_text(size=9),
        legend.title=element_text(size=11),
        panel.grid.major = element_line(color = 'transparent')) +
  coord_sf(datum = NA) +
  scalebar(compartments,dist=2,dd2km=F,st.size=2)

#==============================================================================

#====MOFEP stands map==========================================================

stands = st_read(mofep_db,layer='STAND_BOUNDARY', quiet=T) %>%
  filter(SITE_ID %in% c(3,4)) %>%
  left_join(st_read(mofep_db,layer='TREATMENTS_1996', quiet=T) %>%
            st_set_geometry(NULL),by=c('SITE_ID','STAND_ID')) %>%
  mutate(Harvest = fct_recode(TREATMENT, Clearcut = 'CC', Thin = 'INT',
                              `Single-tree` = 'UAM'),
         Harvest = as.character(Harvest),
         Harvest = ifelse(is.na(Harvest),'No harvest',Harvest),
         
         Harvest = factor(Harvest,levels=c('Clearcut','Single-tree',
                                           'Thin','No harvest'))) %>%
  rename(geometry = Shape) %>%
  st_transform(st_crs(missouri))

stand_coords = st_coordinates(stands)

stand_bounds = compartments %>%
  filter(SITE_ID %in% c(3,4))

pal = colorRampPalette(c("black", "white"))
stand_map  = comp_box %>% ggplot() +
  geom_sf(color='gray') +
  geom_sf(data=stands,aes(fill=Harvest),color='black') + 
  scale_fill_manual(values=c('darkorange2','dodgerblue','gold','gray'))+
  #scale_fill_manual(values=pal(4))+
  geom_sf(data=stand_bounds,fill='transparent',size=1.5,color='black') +
  coord_sf(xlim=range(stand_coords[,'X']),
           ylim=range(stand_coords[,'Y'])) +
  theme_void() +
  theme(axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        legend.position='bottom',
        panel.grid.major = element_line(color = 'transparent')) +
  guides(fill=guide_legend(nrow=2,byrow=TRUE))

#==============================================================================

#====Combine Maps==============================================================

my_arrow = arrow(length = unit(0.1, "inches"))

ggdraw() +
  draw_plot(usa_map, 0, 0.7, 0.5, 0.3) +
  draw_text('A',0.08,0.75,size=16) +
  draw_plot(mo_map, 0.5, 0.7, 0.5, 0.3) +
  draw_text('B',0.86,0.93,size=16) +
  draw_plot(mofep_map,0,0,0.475,0.7) +
  draw_text('C',0.07,0.6,size=16) +
  draw_plot(stand_map,0.525,0,0.45,0.8) +
  draw_text('D',0.57,0.58,size=16) +
  draw_line(x = c(0.31,0.61),y=c(0.862,0.862), arrow=my_arrow) +
  draw_line(x = c(0.80,0.49),y=c(0.77,0.65), arrow=my_arrow) +
  draw_line(x = c(0.39,0.49),y=c(0.48,0.48), arrow=my_arrow)

#ggsave('fig_map.pdf',height=6)
ggsave('fig_map.tiff',height=6,width=6,compression='lzw', dpi=600)

options(warn=0)
