#==============================================================================
#	Effect Size x Taxa Figure
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
library(tidyverse)				#Data processing tools
library(ggplot2)
suppressMessages(library(cowplot))
library(grid)
suppressMessages(library(gridExtra))
theme_set(theme_grey())
suppressMessages(library(rstan))
suppressMessages(library(readxl))
#==============================================================================

#====Read Input Data===========================================================

load('../clean/stan_input.Rdata')
#==============================================================================

#====Select Final Species/Years================================================

st_trap_species = smam_codes$Code[smam_codes$Incidental == 0]
stan_input = stan_input %>%
  mutate(Incidental = ifelse(is.na(Incidental),3,Incidental)) %>%
  filter(! (Incidental == 1 & Species %in% st_trap_species) ) %>%
  filter(! (Incidental == 0 & ! Species %in% st_trap_species) )

species_keep = stan_input %>%
	group_by(Species) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(TotalCount >= 30 & TotalSites >= 20) %>%
	pull(Species)

#Subset to species_keep and create species index codes
stan_input = stan_input %>%
  filter(Species %in% species_keep & !is.na(Effort)) %>%
  mutate(Species = factor(Species, levels=species_keep),
         SpeciesCode = as.numeric(Species))

species_info = stan_input %>%
	group_by(Species,Taxa) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(Species %in% species_keep) %>%
  mutate(TaxaCode = str_to_upper(str_sub(Taxa, 1, 1))) %>%
  rownames_to_column()

#====Read Output Data==========================================================

#Most recent Rdata file
load(paste('../analysis/',
    rev(list.files('../analysis',pattern='model_fit_'))[1],sep=''))
#==============================================================================

#====Extract Posteriors========================================================

betavals = extract(mofep_out, 'beta')$beta

betavals = betavals[,,species_info$Species != 'EUSK']
species_info = species_info %>% filter(Species != 'EUSK')

niter = dim(betavals)[1]
nspecies = dim(betavals)[3]
#==============================================================================

#====Generate Derived Taxa Parameters==========================================

var_ind = c(6,7,10,11,12)
var_name = c('Uneven-aged','Even-aged',
             'Clearcut','Thin',
             'Single-tree selection')

out_mat <- matrix(NA,nrow=niter,ncol=length(var_name))
dist_mat <- matrix(NA,nrow=nspecies, ncol=length(var_name))
colnames(out_mat) <- colnames(dist_mat) <- var_name

for (i in seq_along(var_ind)){ 
  for (j in 1:niter){
    out_mat[j,i] <- mean(abs(betavals[j,var_ind[i],]))
  }
  for (j in 1:nspecies){
    dist_mat[j,i] <- mean(betavals[,var_ind[i],j])
  }
}

out <- data.frame(var = colnames(out_mat), mean = colMeans(out_mat),
                  low = apply(out_mat,2,quantile,0.025),
                  up = apply(out_mat,2,quantile,0.975))
rownames(out) <- NULL

sig_lets <- c('A','A','B','A','A')
eff <- out %>%
  mutate(var = recode(var, 'Single-tree selection' = 'Single-tree'),
         var = factor(var, levels=c('Even-aged','Uneven-aged','Clearcut',
                                    'Thin','Single-tree'))) %>%
  ggplot(aes(x = var, y = mean, color = var)) +
  scale_color_manual(values=c('firebrick2','dodgerblue','darkorange2' ,
                              'forestgreen','darkgoldenrod1')) +
  geom_errorbar(aes(ymin=low,ymax=up, width=0.2),color='black') +
  geom_point(size=3) +
  geom_vline(xintercept=2.5,linetype=2) +
  geom_text(aes(x = var, y = 0.9, label=sig_lets), color='black',
              size=4) +
  ylab('Mean absolute effect size') +
  theme(legend.position='none',
        axis.title.x = element_blank(),
        axis.title.y = element_text(size=8),
        axis.text = element_text(size=6),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        axis.line = element_line(color='black'))

dist <- as.data.frame(dist_mat) %>%
  gather(key = "var", value = "eff") %>%
  mutate(var = recode(var, 'Single-tree selection' = 'Single-tree'),
         var = factor(var, levels=c('Even-aged','Uneven-aged','Clearcut',
                                    'Thin','Single-tree'))) %>%
  ggplot(aes(x = var, y = eff, fill = var)) +
  scale_fill_manual(values=c('firebrick2','dodgerblue','darkorange2' ,
                              'forestgreen','darkgoldenrod1')) +
  geom_hline(yintercept=0) +
  geom_violin(draw_quantiles=0.5) +
  geom_vline(xintercept=2.5,linetype=2) +
  ylab('Effect size') +
  theme(legend.position='none',
        axis.text.y = element_text(size=6),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank(),
        axis.title.x = element_blank(),
        axis.title.y = element_text(size=8),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        axis.line = element_line(color='black'))

#pdf('fig_scale.pdf', height=7, width=7)
#ggdraw() +
#  draw_plot(eff, 0, 0, 1, 0.5) +
#  draw_plot(dist, 0,0.5,1,0.5)
#dev.off()

tiff('fig2_scale.tiff', height=3, width=3, units='in',
     compression='lzw',res=600)
ggdraw() +
  draw_plot(eff, 0, 0, 1, 0.5) +
  draw_plot(dist, 0,0.5,1,0.5)
dev.off()
