#==============================================================================
#	Effect Size x Taxa Figure
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
library(tidyverse)				#Data processing tools
library(ggplot2)
suppressMessages(library(cowplot))
library(grid)
suppressMessages(library(gridExtra))
theme_set(theme_grey())
suppressMessages(library(rstan))
suppressMessages(library(readxl))
#==============================================================================

#====Read Input Data===========================================================

load('../clean/stan_input.Rdata')

herp_groups = read_excel(
  '../data/herps/MOFEP_Herps_1992_2014 combined_finalized.xlsx',
  sheet='SpeciesCode')
#==============================================================================

#====Select Final Species/Years================================================

st_trap_species = smam_codes$Code[smam_codes$Incidental == 0]
stan_input = stan_input %>%
  mutate(Incidental = ifelse(is.na(Incidental),3,Incidental)) %>%
  filter(! (Incidental == 1 & Species %in% st_trap_species) ) %>%
  filter(! (Incidental == 0 & ! Species %in% st_trap_species) )

species_keep = stan_input %>%
	group_by(Species) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(TotalCount >= 30 & TotalSites >= 20) %>%
	pull(Species)

#Subset to species_keep and create species index codes
stan_input = stan_input %>%
  filter(Species %in% species_keep & !is.na(Effort)) %>%
  mutate(Species = factor(Species, levels=species_keep),
         SpeciesCode = as.numeric(Species))

species_info = stan_input %>%
	group_by(Species,Taxa) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(Species %in% species_keep) %>%
  mutate(TaxaCode = str_to_upper(str_sub(Taxa, 1, 1))) %>%
  rownames_to_column()

species_info = species_info %>%
  left_join(herp_groups, by='Species') %>%
  mutate(TaxaEx = case_when(Group == 'Amphibian' ~ 'amphib',
                            Group == 'Reptile' ~ 'rept',
                            TRUE ~ Taxa),
         TaxaEx = factor(TaxaEx, levels=c('smam','bird','amphib','rept'))) %>%
  select(-`Species Name`, -Group, -Subgroup)

#====Read Output Data==========================================================

#Most recent Rdata file
load(paste('../analysis/',
    rev(list.files('../analysis',pattern='model_fit_'))[1],sep=''))
#==============================================================================

#====Extract Posteriors========================================================

betavals = extract(mofep_out, 'beta')$beta

betavals = betavals[,,species_info$Species != 'EUSK']
species_info = species_info %>% filter(Species != 'EUSK')

niter = dim(betavals)[1]

#==============================================================================

#====Generate Derived Taxa Parameters==========================================

var_ind = c(6,7,10,11,12)
var_name = c('Uneven-aged','Even-aged',
             'Clearcut','Thin',
             'Single-tree selection')

for (i in 1:length(var_ind)){

  out_mat = matrix(NA,nrow=niter,ncol=4)
  for (j in 1:niter){
    out_mat[j,1] <- mean(abs(betavals[j,var_ind[i],species_info$TaxaEx=='bird']))
    out_mat[j,2] <- mean(abs(betavals[j,var_ind[i],species_info$TaxaEx=='smam']))
    out_mat[j,3] <- mean(abs(betavals[j,var_ind[i],species_info$TaxaEx=='amphib']))
    out_mat[j,4] <- mean(abs(betavals[j,var_ind[i],species_info$TaxaEx=='rept']))
  }
  
  if(i == 1){
    taxa_data = data.frame(eff=c(out_mat[,1],out_mat[,2],out_mat[,3],out_mat[,4]),
                       Taxa=rep(c('Bird','Smam','Amph','Rept'),each=niter),
                       Variable=var_name[i])
  } else {
    taxa_data = rbind(taxa_data,
                    data.frame(eff=c(out_mat[,1],out_mat[,2],out_mat[,3],out_mat[,4]),
                       Taxa=rep(c('Bird','Smam','Amph','Rept'),each=niter),
                       Variable=var_name[i]))
  }
}

#==============================================================================

#====Reformat and Plot=========================================================

taxa_data = taxa_data %>%
  mutate(Taxa = factor(Taxa, levels=c('Smam','Bird','Amph','Rept')),
         Variable = factor(Variable,
                          levels=c('Clearcut',
                                   'Thin',
                                   'Single-tree selection',
                                   'Even-aged',
                                   'Uneven-aged')))

all_taxa = taxa_data %>%
  mutate(Taxa = 'All') %>%
  group_by(Taxa,Variable) %>%
  summarize(`Mean Absolute Effect Size` = mean(eff),
            low = quantile(eff,0.025),
            up = quantile(eff,0.975))

taxa_data = taxa_data %>%
  group_by(Taxa,Variable) %>%
  summarize(`Mean Absolute Effect Size` = mean(eff),
            low = quantile(eff,0.025),
            up = quantile(eff,0.975)) #%>%
  #rbind(all_taxa) %>%
  #ungroup() %>%
  #mutate(Taxa = factor(Taxa, levels=c('All','Smam','Bird','Amph','Rept')))


plot_func = function(var, letters){
  taxa_data %>%
    filter(Variable == var) %>%
    ggplot(aes(x=Taxa,y=`Mean Absolute Effect Size`, color=Taxa)) +
    ggtitle(var) +
    #scale_color_manual(values=c('gray','firebrick2','dodgerblue','forestgreen','darkgoldenrod1')) +
    scale_color_manual(values=c('firebrick2','dodgerblue','forestgreen','darkgoldenrod1')) +
    #geom_bar(stat='identity') +
    geom_errorbar(aes(ymin=low,ymax=up),width=0.2, color='black',
                  size=0.2) + 
    geom_point(size=1) +
    coord_cartesian(ylim=c(0,1.6)) +
    theme(legend.position='none',
        axis.title = element_blank(),
        axis.text = element_text(size=4),
        plot.title = element_text(hjust=0.5,size=4),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        axis.line = element_line(color='black',size=0.2),
        axis.ticks = element_line(color='black',size=0.2),
        plot.background = element_rect(fill='transparent', color=NA)) +
    geom_text(aes(x = Taxa, y = 1.5, label=letters), color='black',
              size=1.5)
}

out = ggdraw() +
  draw_plot(plot_func('Even-aged',c('AB','A','AB','B')), 
            0.167, 0.48, 0.333, 0.52) +
  draw_plot(plot_func('Uneven-aged',c('A','A','A','A')), 
            0.666, 0.48, 0.333, 0.52) +
  draw_plot(plot_func('Clearcut',c('A','B','A','A')), 
            0, 0, 0.333, 0.52) +
  draw_plot(plot_func('Thin',c('A','A','A','A')), 
            0.333, 0, 0.333, 0.52) +
  draw_plot(plot_func('Single-tree selection',c('A','A','A','A')), 
            0.666, 0, 0.333, 0.52) +
  draw_line(c(0.666,0.666),c(0,1),size=0.3)

y.grob <- textGrob("Mean absolute effect size", 
                   gp=gpar(fontsize=6), rot=90)

x.grob <- textGrob("Taxa", 
                   gp=gpar(fontsize=6))

#add to plot

#pdf('fig_effectsize.pdf', height=7, width=10)
#grid.arrange(arrangeGrob(out, left = y.grob, bottom = x.grob))
#dev.off()

tiff('fig4_effectsize.tiff', height=2.1, width=3, units='in',res=600,
    compression='lzw')
grid.arrange(arrangeGrob(out, left = y.grob, bottom = x.grob))
dev.off()
