#==============================================================================
#	Correlations Figure
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
library(tidyverse)				#Data processing tools
library(ggplot2)
suppressMessages(library(rstan))
suppressMessages(library(readxl))
#==============================================================================

#====Read Input Data===========================================================

load('../clean/stan_input.Rdata')

herp_groups = read_excel(
  '../data/herps/MOFEP_Herps_1992_2014 combined_finalized.xlsx',
  sheet='SpeciesCode')
#==============================================================================

#====Select Final Species/Years================================================

#Remove incidental caps for smams caught in Shermans
st_trap_species = smam_codes$Code[smam_codes$Incidental == 0]
stan_input = stan_input %>%
  mutate(Incidental = ifelse(is.na(Incidental),3,Incidental)) %>%
  filter(! (Incidental == 1 & Species %in% st_trap_species) ) %>%
  filter(! (Incidental == 0 & ! Species %in% st_trap_species) )

species_keep = stan_input %>%
	group_by(Species) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(TotalCount >= 30 & TotalSites >= 20) %>%
	pull(Species)

#Subset to species_keep and create species index codes
stan_input = stan_input %>%
  filter(Species %in% species_keep & !is.na(Effort)) %>%
  mutate(Species = factor(Species, levels=species_keep),
         SpeciesCode = as.numeric(Species))

species_info = stan_input %>%
	group_by(Species,Taxa) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(Species %in% species_keep) %>%
  rownames_to_column()

species_info = species_info %>%
  left_join(herp_groups, by='Species') %>%
  mutate(TaxaEx = case_when(Group == 'Amphibian' ~ 'amphib',
                            Group == 'Reptile' ~ 'rept',
                            TRUE ~ Taxa),
         TaxaEx = factor(TaxaEx, levels=c('smam','bird','amphib','rept'))) %>%
  select(-`Species Name`, -Group, -Subgroup)
#====Read Output Data==========================================================

#Most recent Rdata file
load(paste('../analysis/',
    rev(list.files('../analysis',pattern='model_fit_'))[1],sep=''))
#==============================================================================

#====Extract Posteriors========================================================

betavals = extract(mofep_out, 'beta')$beta

betavals = betavals[,,species_info$Species != 'EUSK']
species_info = species_info %>% filter(Species != 'EUSK')

##

taxas <- list(All=c('amphib','rept','bird','smam'),Smam='smam',Bird='bird',
              Amph='amphib',Rept='rept')

comps <- list('Even-aged vs. Uneven-aged'=c(6,7),
              'Even-aged vs. Regen'=c(7,10),
              'Even-aged vs. Thin'=c(7,11),
              'Uneven-aged vs. Single-tree' = c(6,12))

r_post <- function(taxa, comp_no){
  tname = names(taxas)[taxa]
  beta_sub = betavals[,comps[[comp_no]],species_info$TaxaEx %in% taxas[[taxa]]]
  get_cor = function(x){cor(t(x))[1,2]}
  post = apply(beta_sub, 1, get_cor)
  out = c(tname,names(comps)[comp_no],
          mean(post),quantile(post,0.025),quantile(post,0.975))
  names(out) = c('Taxa','Comparison','mean','low','up')
  as.data.frame(t(out))
}

fig_inp = r_post(1,1)
for (i in 2:5){
  fig_inp = rbind(fig_inp,r_post(i,1))
}
for (i in 2:4){
  for (j in 1:5){
    fig_inp = rbind(fig_inp, r_post(j,i))
}}

fig_inp = fig_inp %>%
  mutate(`Pearson's r` = as.numeric(as.character(mean)),
         low = as.numeric(as.character(low)),
         up = as.numeric(as.character(up)),
         letter = c('','AB','A','B','B',
                    '','A','B','A','A',
                    '','AB','A','B','AB',
                    '','A','A','A','A'))

out = fig_inp %>% 
  
  ggplot(aes(x = Taxa, y = `Pearson's r`, color=Taxa)) +
  geom_hline(yintercept=0,linetype=2,size=0.2) +
  geom_errorbar(aes(ymin=low,ymax=up),width=0.2, color='black',size=0.2) + 
  scale_color_manual(values=c('gray','firebrick2','dodgerblue','forestgreen',
                              'darkgoldenrod1')) +
  geom_point(size=2) +
  ylab("Pearson's r") +
  geom_text(aes(x = Taxa, y = 1.05, label=letter),size=2, color='black') +
  theme(legend.position='none',
        axis.text = element_text(size=6),
        axis.title = element_text(size=8),
        strip.text.x = element_text(size=6),
        plot.title = element_text(hjust=0.5),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        axis.line = element_line(color='black',size=0.2),
        axis.ticks = element_line(color='black',size=0.2),
        plot.background = element_rect(fill='transparent', color=NA)) +
  facet_wrap(~Comparison)

ggsave('fig5_correlations.tiff',height=3,width=3,dpi=600,compression='lzw')
#ggsave('fig_correlations.pdf')
