#==============================================================================
# Clustering Figure
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
library(tidyverse)				#Data processing tools
library(ggplot2)
suppressMessages(library(cowplot))
theme_set(theme_grey())
suppressMessages(library(factoextra))
suppressMessages(library(rstan))
suppressMessages(library(readxl))
#==============================================================================

#====Read Input Data===========================================================

load('../clean/stan_input.Rdata')

herp_groups = read_excel(
              '../data/herps/MOFEP_Herps_1992_2014 combined_finalized.xlsx',
                         sheet='SpeciesCode')
#==============================================================================

#====Select Final Species/Years================================================

#Remove incidental caps for smams caught in Shermans
st_trap_species = smam_codes$Code[smam_codes$Incidental == 0]
stan_input = stan_input %>%
  mutate(Incidental = ifelse(is.na(Incidental),3,Incidental)) %>%
  filter(! (Incidental == 1 & Species %in% st_trap_species) ) %>%
  filter(! (Incidental == 0 & ! Species %in% st_trap_species) )

species_keep = stan_input %>%
	group_by(Species) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(TotalCount >= 30 & TotalSites >= 20) %>%
	pull(Species)

#Subset to species_keep and create species index codes
stan_input = stan_input %>%
  filter(Species %in% species_keep & !is.na(Effort)) %>%
  mutate(Species = factor(Species, levels=species_keep),
         SpeciesCode = as.numeric(Species))

species_info = stan_input %>%
	group_by(Species,Taxa) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(Species %in% species_keep) %>%
  mutate(TaxaCode = str_to_upper(str_sub(Taxa, 1, 1))) %>%
  rownames_to_column()

species_info = species_info %>%
  left_join(herp_groups, by='Species') %>%
  mutate(TaxaEx = case_when(Group == 'Amphibian' ~ 'Amph',
                            Group == 'Reptile' ~ 'Rept',
                            TRUE ~ Taxa),
         TaxaEx = factor(TaxaEx, levels=c('smam','bird','Amph','Rept')),
         Taxa = fct_recode(TaxaEx, Smam='smam',Bird='bird')) %>%
  select(-`Species Name`, -Group, -Subgroup)
#====Read Output Data==========================================================

#Most recent Rdata file
load(paste('../analysis/',
    rev(list.files('../analysis',pattern='model_fit_'))[1],sep=''))
#==============================================================================

#====Extract Posteriors========================================================

betavals = extract(mofep_out, 'beta')$beta

beta_means = t(apply(betavals,c(2,3),mean))

beta_sub = beta_means[,c(6:7)]
colnames(beta_sub) = c('unev','ev')
rownames(beta_sub) = NULL

beta_sub = beta_sub[species_info$Species != 'EUSK',]

species_info = species_info %>% filter(Species != 'EUSK')

nclust = fviz_nbclust(beta_sub, kmeans, method = "wss",
                      linecolor='black') +
    geom_vline(xintercept = 5, linetype = 2,size=0.2) +
    ylab('Total SSQ') +
    xlab('Clusters k') +
    theme(
        plot.title = element_text(size=4),
        axis.text = element_text(size=4),
        axis.title = element_text(size=4),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        axis.line = element_line(color='black',size=0.2),
        axis.ticks = element_line(color='black',size=0.2),
        plot.background = element_rect(fill='transparent', color=NA))

set.seed(456)
test = kmeans(beta_sub,centers=5)

# Computing convex hulls
conv_data = cbind(beta_sub,clust=test$cluster) %>% as_tibble()
s = conv_data %>% split(.$clust)
ch = s %>% lapply(., function(el) chull(el$unev, el$ev))
# Get points for each sub-data.frame using names index
ch = lapply(names(ch), function(x) s[[x]][ch[[x]],]) %>%   
  do.call(rbind, .) 

fig_data = data.frame(`Uneven-aged Effect`=beta_sub[,1],
                      `Even-aged Effect`=beta_sub[,2], 
                      Taxa=species_info$Taxa,check.names=F,
                      Species=species_info$Species)

fig_sub <- fig_data %>% as_tibble() %>%
  filter(Species %in% c('PLAL','EULU','PRAW','YBCH','INBU',
                        'SOTA','OVEN','RACA','NOVI','KEWA',
                        'WOTH','STDE'))

adjust_vert <- 0.7*c(0.1,-0.1,0.05,0,0,-0.1,0,-0.1,-0.1,0,0.1)
adjust_horiz <- 1.4*c(0,0,-0.1,0.1,-0.1,0,-0.1,0,0,0.1,0)

p = fig_data %>%
  ggplot(aes(x=`Uneven-aged Effect`, y=`Even-aged Effect`)) +
  geom_vline(xintercept=0,linetype='dashed',size=0.2) +
  geom_hline(yintercept=0,linetype='dashed',size=0.2) +
  geom_polygon(data=ch,aes(x=unev,y=ev,group=clust),fill='grey55',
               alpha=0.5) +
  geom_point(aes(color=Taxa),size=1) + 
  annotate("text", x=test$centers[,1],y=test$centers[,2],label=c(1,5,2,3,4),
           size=6) +
  geom_text(data=fig_sub,
            aes(x=`Uneven-aged Effect`+adjust_horiz, 
                y=`Even-aged Effect`+adjust_vert,
                label=Species),size=2) +
  scale_color_manual(values=c('firebrick2','dodgerblue',
                              'forestgreen','darkgoldenrod1')) +
  ylab('Even-aged effect') + xlab('Uneven-aged effect') +
  theme(legend.position = c(0.9,0.25),
        legend.title = element_blank(),
        legend.text = element_text(size=6),
        legend.key=element_blank(),
        axis.text = element_text(size=6),
        axis.title = element_text(size=6),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        axis.line = element_line(color='black',size=0.2),
        axis.ticks = element_line(color='black',size=0.2),
        plot.background = element_rect(fill='transparent', color=NA))

#out = ggdraw() +
#  draw_plot(p,0,0,1,1) +
#  draw_plot(nclust,0.15,0.67,0.3,0.3)

#ggsave('fig_clustering.pdf', height=7, bg='transparent')
ggsave('fig6_clustering.tiff', height=3, width=3, dpi=600,
       compression='lzw')
