#==============================================================================
#	Effect Size x Species Figures
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
library(tidyverse)				#Data processing tools
suppressMessages(library(rstan))
library(ggplot2)
library(cowplot)
theme_set(theme_grey())
library(grid)
library(gridExtra)
#==============================================================================

#====Read Output Data==========================================================

#Most recent Rdata file
load(paste('../analysis/',
    rev(list.files('../analysis',pattern='model_richness_fit_'))[1],sep=''))

#==============================================================================

#====Extract Posteriors========================================================

rich_array = array(NA,dim=c(300,12,4))
rich_array[,,1] = extract(rich_smam_out,'beta')$beta
rich_array[,,2] = extract(rich_birds_out,'beta')$beta
rich_array[,,3] = extract(rich_amphib_out,'beta')$beta
rich_array[,,4] = extract(rich_rept_out,'beta')$beta

betameans = apply(rich_array,c(2,3),mean)
betaup = apply(rich_array,c(2,3),quantile,0.975)
betalow = apply(rich_array,c(2,3),quantile,0.025)

#unev, ev, clear, thin, singletree
keep_inds <- c(6,7,10,11,12)

betameans <- betameans[keep_inds,]
betaup <- betaup[keep_inds,]
betalow <- betalow[keep_inds,]

var_names <- c('Uneven-aged','Even-aged','Clearcut','Thin',
             'Single-tree selection')

make_tidy <- function(raw){
  colnames(raw) <- c('Smam','Bird','Amph','Rept')
  raw %>%
    as_tibble() %>%
    mutate(Variable = var_names) %>%
    gather(key='Taxa',value='value',Smam:Rept)
}

taxa_data <- make_tidy(betameans) %>%
  left_join(make_tidy(betalow),by=c('Variable','Taxa')) %>%
  left_join(make_tidy(betaup),by=c('Variable','Taxa')) %>%
  mutate(Taxa = factor(Taxa, levels=c('Smam','Bird','Amph','Rept')))

names(taxa_data) <- c('Variable','Taxa','Effect Size','low','up')
#==============================================================================

post_hoc <- function(Variable){
  ind <- keep_inds[which(var_names == Variable)] 
  sub <- rich_array[,ind,]
  out <- rep(NA,6)
  names(out) <- c('SvB','SvA','SvR','BvA','BvR','AvR')

  comp <- function(col1, col2){
    diff <- quantile(col1-col2,c(0.025,0.975))
    if(all(diff>0)|all(diff<0)) return(TRUE)
    return(FALSE)
  }

  out[1] <- comp(sub[,1],sub[,2])
  out[2] <- comp(sub[,1],sub[,3])
  out[3] <- comp(sub[,1],sub[,4])
  out[4] <- comp(sub[,2],sub[,3])
  out[5] <- comp(sub[,2],sub[,4])
  out[6] <- comp(sub[,3],sub[,4])
  out
}

#post_hoc('Even-aged')
#post_hoc('Uneven-aged')
#post_hoc('Clearcut')
#post_hoc('Thin')
#post_hoc('Single-tree selection')

plot_func = function(var, letters){
  taxa_data %>%
    filter(Variable == var) %>%
    ggplot(aes(x=Taxa,y=`Effect Size`, color=Taxa)) +
    ggtitle(var) +
    #scale_color_manual(values=c('gray','firebrick2','dodgerblue','forestgreen','darkgoldenrod1')) +
    scale_color_manual(values=c('firebrick2','dodgerblue','forestgreen','darkgoldenrod1')) +
    #geom_bar(stat='identity') +
    geom_hline(yintercept=0,linetype=2,size=0.2) +
    geom_errorbar(aes(ymin=low,ymax=up),width=0.2, color='black',
                  size=0.2) + 
    geom_point(size=1) +
    coord_cartesian(ylim=c(-0.3,0.63)) +
    theme(legend.position='none',
        axis.title = element_blank(),
        axis.text = element_text(size=4),
        plot.title = element_text(hjust=0.5,size=4),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        axis.line = element_line(color='black',size=0.2),
        axis.ticks = element_line(color='black',size=0.2),
        plot.background = element_rect(fill='transparent', color=NA)) +
    geom_text(aes(x = Taxa, y = 0.63, label=letters), color='black',
              size=1.5)
}

out = ggdraw() +
  draw_plot(plot_func('Even-aged',c('A','A','A','A')), 
            0.167, 0.48, 0.333, 0.52) +
  draw_plot(plot_func('Uneven-aged',c('AB','A','B','AB')), 
            0.666, 0.48, 0.333, 0.52) +
  draw_plot(plot_func('Clearcut',c('A','B','B','AB')), 
            0, 0, 0.333, 0.52) +
  draw_plot(plot_func('Thin',c('A','B','AB','A')), 
            0.333, 0, 0.333, 0.52) +
  draw_plot(plot_func('Single-tree selection',c('A','A','A','A')), 
            0.666, 0, 0.333, 0.52) +
  draw_line(c(0.666,0.666),c(0,1),size=0.3)

y.grob <- textGrob("Effect size", 
                   gp=gpar(fontsize=6), rot=90)

x.grob <- textGrob("Taxa", 
                   gp=gpar(fontsize=6))


tiff('fig7_richness.tiff', height=2.1, width=3, units='in',res=600,
    compression='lzw')
grid.arrange(arrangeGrob(out, left = y.grob, bottom = x.grob))
dev.off()

