#==============================================================================
#	Effect Size x Taxa Figure
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
library(tidyverse)				#Data processing tools
library(ggplot2)
suppressMessages(library(cowplot))
library(grid)
suppressMessages(library(gridExtra))
theme_set(theme_grey())
suppressMessages(library(rstan))
suppressMessages(library(readxl))
#==============================================================================

#====Read Input Data===========================================================

load('../../clean/stan_input.Rdata')

herp_groups = read_excel('../../data/herps/MOFEP_Herps_1992_2014 combined_finalized.xlsx',
                         sheet='SpeciesCode')

#==============================================================================

#====Select Final Species/Years================================================

#Remove incidental caps for smams caught in Shermans
st_trap_species = smam_codes$Code[smam_codes$Incidental == 0]
stan_input = stan_input %>%
  mutate(Incidental = ifelse(is.na(Incidental),3,Incidental)) %>%
  filter(! (Incidental == 1 & Species %in% st_trap_species) ) %>%
  filter(! (Incidental == 0 & ! Species %in% st_trap_species) )

species_keep = stan_input %>%
	group_by(Species) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(TotalCount >= 30 & TotalSites >= 20) %>%
	pull(Species)

#Subset to species_keep and create species index codes
stan_input = stan_input %>%
  filter(Species %in% species_keep & !is.na(Effort)) %>%
  mutate(Species = factor(Species, levels=species_keep),
         SpeciesCode = as.numeric(Species))

species_info = stan_input %>%
	group_by(Species,Taxa) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(Species %in% species_keep) %>%
  mutate(TaxaCode = str_to_upper(str_sub(Taxa, 1, 1))) %>%
  rownames_to_column()

species_info = species_info %>%
  left_join(herp_groups, by='Species') %>%
  mutate(TaxaEx = case_when(Group == 'Amphibian' ~ 'amphib',
                            Group == 'Reptile' ~ 'rept',
                            TRUE ~ Taxa),
         TaxaEx = factor(TaxaEx, levels=c('smam','bird','amphib','rept'))) %>%
  select(-`Species Name`, -Group, -Subgroup)


#====Read Output Data==========================================================

#Most recent Rdata file
load(paste('../../analysis/',
    rev(list.files('../../analysis',pattern='model_fit_'))[1],sep=''))
#==============================================================================

#====Extract Posteriors========================================================

betavals = extract(mofep_out, 'beta')$beta

niter = dim(betavals)[1]

mns = apply(betavals,c(2,3),mean)

#==============================================================================

#====Generate Derived Taxa Parameters==========================================

var_ind = c(6,7,10,11,12)
var_name = c('Uneven-aged','Even-aged',
             'Regen','Thin',
             'Single-tree selection')
nspecies = dim(mns)[2]

for (i in 1:length(var_ind)){

  if(i == 1){
    taxa_data = data.frame(eff = mns[var_ind[i],],
                       Taxa=species_info$TaxaEx,
                       Variable=var_name[i])
  } else {
    taxa_data = rbind(taxa_data,
                      data.frame(eff = mns[var_ind[i],],
                       Taxa=species_info$TaxaEx,
                       Variable=var_name[i]))
  }
}

#==============================================================================

#====Reformat and Plot=========================================================

taxa_data = taxa_data %>%
  rename(`Effect Size` = eff) %>%
  mutate(#Taxa = factor(Taxa,levels=c('smam','bird','herp')),
         Taxa = fct_recode(Taxa, Smam='smam', Bird='bird',
                           Amphib='amphib',Rept='rept'),
         Variable = factor(Variable,
                          levels=c('Regen',
                                   'Thin',
                                   'Single-tree selection',
                                   'Even-aged',
                                   'Uneven-aged')))

plot_func <- function(var){
  taxa_data %>%
    filter(Variable == var) %>%
    ggplot(aes(x=Taxa,y=`Effect Size`, fill=Taxa)) +
    ggtitle(var) +
    scale_fill_manual(values=c('firebrick2','dodgerblue','forestgreen','darkgoldenrod1')) +
    geom_hline(yintercept=0) +
    geom_violin(draw_quantiles=0.5) +
    coord_cartesian(ylim=c(-2,3.5)) +
    theme(legend.position='none',
        axis.title = element_blank(),
        axis.text = element_text(size=10),
        plot.title = element_text(hjust=0.5),
        plot.background = element_rect(fill='transparent', color=NA))
}

out = ggdraw() +
  draw_plot(plot_func('Even-aged'), 0.167, 0.5, 0.333, 0.5) +
  draw_plot(plot_func('Uneven-aged'), 0.666, 0.5, 0.333, 0.5) +

  draw_plot(plot_func('Regen'), 0, 0, 0.333, 0.5) +
  draw_plot(plot_func('Thin'), 0.333, 0, 0.333, 0.5) +
  draw_plot(plot_func('Single-tree selection'), 0.666, 0, 0.333, 0.5) +
  draw_line(c(0.666,0.666),c(0,1))

y.grob <- textGrob("Effect Size", 
                   gp=gpar(fontsize=20), rot=90)

x.grob <- textGrob("Taxa", 
                   gp=gpar(fontsize=20))

#add to plot

pdf('fig_boxplot.pdf', height=4.5)
grid.arrange(arrangeGrob(out, left = y.grob, bottom = x.grob))
dev.off()
#ggsave('fig_boxplot.pdf', height=4.5, bg='transparent')

#Partial
out2 = ggdraw() +
  draw_plot(plot_func('Even-aged'), 0.167, 0.5, 0.333, 0.5) +
  draw_plot(plot_func('Uneven-aged'), 0.666, 0.5, 0.333, 0.5) +
  draw_line(c(0.666,0.666),c(0,1))

pdf('fig_boxplot_partial.pdf', height=4.5)
grid.arrange(arrangeGrob(out2, left = y.grob, bottom = x.grob))
dev.off()
#ggsave('fig_boxplot_partial.pdf', height=4.5, bg='transparent')
#==============================================================================


