#==============================================================================
# Clustering Figure
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
library(tidyverse)				#Data processing tools
library(ggplot2)
suppressMessages(library(cowplot))
suppressMessages(library(factoextra))
suppressMessages(library(rstan))
suppressMessages(library(readxl))
#==============================================================================

#====Read Input Data===========================================================

load('../../clean/stan_input.Rdata')

herp_groups = read_excel('../../data/herps/MOFEP_Herps_1992_2014 combined_finalized.xlsx',
                         sheet='SpeciesCode')
#==============================================================================

#====Select Final Species/Years================================================

#Remove incidental caps for smams caught in Shermans
st_trap_species = smam_codes$Code[smam_codes$Incidental == 0]
stan_input = stan_input %>%
  mutate(Incidental = ifelse(is.na(Incidental),3,Incidental)) %>%
  filter(! (Incidental == 1 & Species %in% st_trap_species) ) %>%
  filter(! (Incidental == 0 & ! Species %in% st_trap_species) )

species_keep = stan_input %>%
	group_by(Species) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(TotalCount >= 30 & TotalSites >= 20) %>%
	pull(Species)

#Subset to species_keep and create species index codes
stan_input = stan_input %>%
  filter(Species %in% species_keep & !is.na(Effort)) %>%
  mutate(Species = factor(Species, levels=species_keep),
         SpeciesCode = as.numeric(Species))

species_info = stan_input %>%
	group_by(Species,Taxa) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(Species %in% species_keep) %>%
  mutate(TaxaCode = str_to_upper(str_sub(Taxa, 1, 1))) %>%
  rownames_to_column()

species_info = species_info %>%
  left_join(herp_groups, by='Species') %>%
  mutate(TaxaEx = case_when(Group == 'Amphibian' ~ 'Amphib',
                            Group == 'Reptile' ~ 'Rept',
                            TRUE ~ Taxa),
         TaxaEx = factor(TaxaEx, levels=c('smam','bird','Amphib','Rept')),
         Taxa = fct_recode(TaxaEx, Smam='smam',Bird='bird')) %>%
  select(-`Species Name`, -Group, -Subgroup)
#====Read Output Data==========================================================

#Most recent Rdata file
load(paste('../../analysis/',
    rev(list.files('../../analysis',pattern='model_fit_'))[1],sep=''))
#==============================================================================

#====Extract Posteriors========================================================

betavals = extract(mofep_out, 'beta')$beta

beta_means = t(apply(betavals,c(2,3),mean))

beta_sub = beta_means[,c(6:7)]
colnames(beta_sub) = c('unev','ev')
rownames(beta_sub) = NULL

nclust = fviz_nbclust(beta_sub, kmeans, method = "wss",
                      linecolor='black') +
    geom_vline(xintercept = 5, linetype = 2) +
    ylab('Total SSQ') +
    xlab('Clusters k') +
    theme_grey() +
    theme(plot.title=element_blank())

set.seed(456)
test = kmeans(beta_sub,centers=5)

pal = colorRampPalette(c("gray55"))
#pal = colorRampPalette(c("black", "gray"))
p = fviz_cluster(test, data=beta_sub, geom="line", ellipse=T, stand=F) +
  scale_fill_manual(values=pal(5)) +
  scale_color_manual(values=c(pal(5),'forestgreen','dodgerblue','darkgoldenrod1',
                              'firebrick2')) +
  theme(legend.position = 'none',
        axis.title = element_text(size=20),
        axis.text = element_text(size=14),
        plot.title = element_blank(),
        plot.background = element_rect(fill='transparent', color=NA)) +
  geom_vline(xintercept=0,linetype='dashed') +
  geom_hline(yintercept=0,linetype='dashed') +
  #geom_ribbon(stat='smooth', method = "lm", se=TRUE, alpha=0.1) +
  #annotate("text", x=beta_sub[,1], y=beta_sub[,2],
  #         label=species_info$TaxaCode, size=5) +
  geom_point(data=data.frame(unev=beta_sub[,1],ev=beta_sub[,2],
                                Taxa=species_info$Taxa), 
             aes(x=unev, y=ev, color=Taxa), size=2) +
  annotate("text", x=test$centers[,1],y=test$centers[,2],label=c(1,2,5,3,4),
           size=14) +
  #geom_line(stat="smooth",method = "lm",size = 0.5, alpha = 0.5) +
  labs(x = 'Uneven-aged Effect', y = 'Even-aged Effect')
p

out = ggdraw() +
  draw_plot(p,0,0,1,1) +
  draw_plot(nclust,0.15,0.67,0.3,0.3)

ggsave('fig_clustering.pdf', height=4.5, bg='transparent')
