#==============================================================================
#	Correlations Figure
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
library(tidyverse)				#Data processing tools
library(ggplot2)
suppressMessages(library(rstan))
suppressMessages(library(readxl))
#==============================================================================

#====Read Input Data===========================================================

load('../../clean/stan_input.Rdata')

herp_groups = read_excel('../../data/herps/MOFEP_Herps_1992_2014 combined_finalized.xlsx',
                         sheet='SpeciesCode')
#==============================================================================

#====Select Final Species/Years================================================

#Remove incidental caps for smams caught in Shermans
st_trap_species = smam_codes$Code[smam_codes$Incidental == 0]
stan_input = stan_input %>%
  mutate(Incidental = ifelse(is.na(Incidental),3,Incidental)) %>%
  filter(! (Incidental == 1 & Species %in% st_trap_species) ) %>%
  filter(! (Incidental == 0 & ! Species %in% st_trap_species) )

species_keep = stan_input %>%
	group_by(Species) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(TotalCount >= 30 & TotalSites >= 20) %>%
	pull(Species)

#Subset to species_keep and create species index codes
stan_input = stan_input %>%
  filter(Species %in% species_keep & !is.na(Effort)) %>%
  mutate(Species = factor(Species, levels=species_keep),
         SpeciesCode = as.numeric(Species))

species_info = stan_input %>%
	group_by(Species,Taxa) %>%
	summarize(TotalCount = sum(n, na.rm=T),
			  TotalSites = sum(n > 0)) %>%
	filter(Species %in% species_keep) %>%
  rownames_to_column() %>%
  mutate(Taxa = case_when(Taxa == 'herp' ~ 'Herp',
                          Taxa == 'bird' ~ 'Bird',
                          Taxa == 'smam' ~ 'Smam'))

species_info = species_info %>%
  ungroup() %>%
  left_join(herp_groups, by='Species') %>%
  mutate(TaxaEx = case_when(Group == 'Amphibian' ~ 'amphib',
                            Group == 'Reptile' ~ 'rept',
                            TRUE ~ Taxa),
         TaxaEx = factor(TaxaEx, levels=c('Smam','Bird','amphib','rept')),
         Taxa = fct_recode(TaxaEx, Amphib='amphib',Rept='rept')) %>%
  select(-`Species Name`, -Group, -Subgroup)
#====Read Output Data==========================================================

#Most recent Rdata file
load(paste('../../analysis/',
    rev(list.files('../../analysis',pattern='model_fit_'))[1],sep=''))
#==============================================================================

#====Extract Posteriors========================================================

betavals = extract(mofep_out, 'beta')$beta

beta_means = t(apply(betavals,c(2,3),mean))
beta_low = t(apply(betavals,c(2,3),quantile,0.025))
beta_up = t(apply(betavals,c(2,3),quantile,0.975))

beta_sig = t(apply(betavals,c(2,3),function(x){
                     bounds = quantile(x,c(0.025,0.975))
                     if(all(bounds>0)|all(bounds<0)){
                       return(TRUE)
                     }else{return(FALSE)}}))

##
#pal = colorRampPalette(c("black", "gray"))
pal = colorRampPalette(c('firebrick2','dodgerblue','forestgreen','darkgoldenrod1'))

beta_sub = as.tibble(beta_means[,c(6,7)])
colnames(beta_sub) = c('Uneven-aged Effect', 'Even-aged Effect')



beta_taxa = beta_sub %>%
  mutate(species = species_info$rowname,
         Taxa = species_info$Taxa)

beta_smam = beta_taxa %>% filter(Taxa == 'Smam')
R2_smam = round(cor(beta_smam[,1],beta_smam[,2])^2,2) 
beta_bird = beta_taxa %>% filter(Taxa == 'Bird')
R2_bird = round(cor(beta_bird[,1],beta_bird[,2])^2,2) 
beta_amphib = beta_taxa %>% filter(Taxa == 'Amphib')
R2_amphib = round(cor(beta_amphib[,1],beta_amphib[,2])^2,2) 
beta_rept = beta_taxa %>% filter(Taxa == 'Rept')
R2_rept = round(cor(beta_rept[,1],beta_rept[,2])^2,2) 

p0 = beta_taxa %>% 
  ggplot(aes(x=`Uneven-aged Effect`,y=`Even-aged Effect`)) + 
  scale_color_manual(values=pal(4)) +
  coord_cartesian(y=c(-0.5,1.4)) +
  theme(legend.position=c(0.15,0.8),
        axis.title = element_text(size=20),
        axis.text = element_text(size=14),
        legend.title = element_text(size=18),
        legend.text = element_text(size=16),
        plot.title = element_blank(),
        plot.background = element_rect(fill='transparent', color=NA)) +
  geom_hline(aes(yintercept=0),linetype='dashed') +
  geom_vline(aes(xintercept=0),linetype='dashed') +
  geom_line(aes(group=Taxa, color=Taxa),stat="smooth",
            method = "lm",size = 1) +
  geom_point(aes(color=Taxa), size=2) +
  annotate('text',x=0.5,y=1,label=sprintf("R^2 == '%0.2f'", R2_bird),
           size=7,parse=T, color='dodgerblue') +
  annotate('text',x=0.9,y=0.45,label=sprintf("R^2 == '%0.2f'", R2_smam),
           size=7,parse=T, color='firebrick2') +
  annotate('text',x=-0.3,y=0.35,label=sprintf("R^2 == '%0.2f'", R2_amphib),
           size=7,parse=T, color='forestgreen') +
  annotate('text',x=1.15,y=0.22,label=sprintf("R^2 == '%0.2f'", R2_amphib),
           size=7,parse=T, color='darkgoldenrod1')

ggsave('fig_correlation_bytaxa.pdf', height=4.5, bg='transparent')
