#==============================================================================
#	MOFEP map in R
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
suppressMessages(library(sf))			#Spatial data tools
library(tidyverse)				#Data processing tools
suppressMessages(library(tigris))
suppressMessages(library(ggplot2))
suppressMessages(library(ggsn))
suppressMessages(library(cowplot))
#==============================================================================

#====USA and MO Maps===========================================================
options(warn=-1)
print('Downloading boundary data from TIGRIS')

missouri = counties(class='sf',state=29, cb=TRUE) %>%
  st_transform('+proj=utm +zone=15 +datum=NAD83 +units=m +no_defs') %>%
  mutate(is_mofep = 
         ifelse(NAME %in% c('Reynolds','Shannon','Carter'),TRUE,FALSE))

mo_map = missouri %>%
  ggplot() +
  geom_sf(aes(fill=is_mofep)) +
  scale_fill_manual(values=c('white','gray')) +
  coord_sf(datum = NA) +
  theme_void() +
  theme(legend.position='none',
        panel.border = element_rect(color='black',fill=NA,size=1))

loc_counties = missouri %>%
  filter(is_mofep)

#==============================================================================

#====MOFEP compartments map====================================================

#MOFEP geodatabase
mofep_db = '../../data/MOFEP.gdb'

compartments = st_read(mofep_db,layer='SITE_BOUNDARY',quiet=T) %>%
  rename(geometry = Shape,
         Treatment = TREATMENT) %>%
  mutate(Treatment = fct_recode(Treatment, `Control` = 'NO HARVEST',
                                `Uneven-aged` = 'UNEVEN-AGED',
                                `Even-aged` = 'EVEN-AGED'),
         Treatment = factor(Treatment,levels=c('Even-aged','Uneven-aged',
                                               'Control'))) %>%
  st_transform(st_crs(loc_counties))

comp_coords = st_coordinates(compartments)

mofep_map = loc_counties %>% ggplot() +
  geom_sf() +
  geom_sf(data=compartments,aes(fill=Treatment)) +
  scale_fill_manual(values=c('firebrick','dodgerblue4','forestgreen')) +
  coord_sf(xlim=range(comp_coords[,'X']),
           ylim=range(comp_coords[,'Y'])) +
  theme(axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x=element_text(size=12),
        axis.text.y=element_text(size=12),
        legend.position=c(0.53,0.23),
        legend.text=element_text(size=18),
        legend.title=element_text(size=20),
        panel.grid.major = element_line(color = 'transparent')) +
  scalebar(compartments,dist=2,dd2km=F,st.size=2)

#==============================================================================

#====MOFEP stands map==========================================================

stands = st_read(mofep_db,layer='STAND_BOUNDARY', quiet=T) %>%
  filter(SITE_ID %in% c(3,4)) %>%
  left_join(st_read(mofep_db,layer='TREATMENTS_1996', quiet=T) %>%
            st_set_geometry(NULL),by=c('SITE_ID','STAND_ID')) %>%
  mutate(Harvest = fct_recode(TREATMENT, Regen = 'CC', Thin = 'INT',
                              `Single-tree` = 'UAM'),
         Harvest = as.character(Harvest),
         Harvest = ifelse(is.na(Harvest),'No harvest',Harvest),
         Harvest = factor(Harvest,levels=c('Regen','Single-tree',
                                           'Thin','No harvest'))) %>%
  rename(geometry = Shape)

stand_coords = st_coordinates(stands)

stand_bounds = compartments %>%
  filter(SITE_ID %in% c(3,4))

stand_map  = loc_counties %>% ggplot() +
  geom_sf() +
  geom_sf(data=stands,aes(fill=Harvest),color='black') +
  scale_fill_manual(values=c('darkorange2','dodgerblue','gold','gray'))+
  geom_sf(data=stand_bounds,fill='transparent',size=1.5,color='black') +
  coord_sf(xlim=range(stand_coords[,'X']),
           ylim=range(stand_coords[,'Y'])) +
  theme_void() +
  theme(axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        legend.position='bottom',
        legend.text=element_text(size=18),
        legend.title=element_text(size=20),
        panel.grid.major = element_line(color = 'transparent')) +
  guides(fill=guide_legend(nrow=2,byrow=TRUE))

ggsave('fig_stands.pdf',height=7)

#==============================================================================

#====Final Maps================================================================

#MOFEP map

out1 = ggdraw() +
  draw_plot(mofep_map,0,0,1,1) +
  draw_plot(mo_map,0.2,0.48,0.25,0.25)

ggsave('fig_compartments.pdf',height=7)

subregion_box = st_as_sfc(st_bbox(st_buffer(stand_bounds,500)))
mofep_map_hl = mofep_map +
  geom_sf(data=subregion_box,fill=NA,color='black',size=1.5) +
  coord_sf(xlim=range(comp_coords[,'X']),
           ylim=range(comp_coords[,'Y']))

ggsave('fig_compartments_hl.pdf',height=7)

#====Timeline Maps=============================================================

time_stands = st_read(mofep_db,layer='STAND_BOUNDARY', quiet=T) %>%
  filter(SITE_ID %in% c(5,6)) %>%
  left_join(st_read(mofep_db,layer='TREATMENTS_1996', quiet=T) %>%
            st_set_geometry(NULL),by=c('SITE_ID','STAND_ID')) %>%
  mutate(Harvest96 = fct_recode(TREATMENT, Regen = 'CC', Thin = 'INT',
                              `Single-tree` = 'UAM'),
         Harvest96 = as.character(Harvest96),
         Harvest96 = ifelse(is.na(Harvest96),'No harvest',Harvest96),
         Harvest96 = factor(Harvest96,levels=c('Regen',
                                           'Thin','No harvest'))) %>%
  left_join(st_read(mofep_db,layer='TREATMENTS_2011', quiet=T) %>%
            st_set_geometry(NULL), by=c('SITE_ID','STAND_ID')) %>%
  mutate(Harvest11 = case_when(PRES_DESC %in% 
                               c('CLEARCUT','REGENERATE OAK SHELTERWOOD') ~ 'Regen',
                               PRES_DESC == 'INTERMEDIATE EVEN-AGE THIN' ~ 'Thin',
                               TRUE ~ 'No harvest'),
         Harvest11 = factor(Harvest11,levels=c('Regen','Thin','No harvest'))) %>%
  rename(geometry = Shape)

stand_coords = st_coordinates(time_stands)

stand_bounds = compartments %>%
  filter(SITE_ID %in% c(5,6))

stand_centers = stand_bounds %>% st_centroid() %>% st_coordinates %>%
  as_tibble() %>%
  mutate(Name = c('Even-aged','Control'))

stand_map92 = time_stands %>%
  mutate(Harvest = 'No harvest',
         Harvest = factor(Harvest,levels=c('Regen','Thin',
                                           'Previous harvest','No harvest'))) %>%
  ggplot() +
  ggtitle('Before (1992-1996)') +
  geom_sf(aes(fill=Harvest),color='black') +
  scale_fill_manual(values=c('darkorange2','gold','darkorange4','gray'),
                    drop=FALSE)+
  geom_sf(data=stand_bounds,fill='transparent',size=1.5,color='black') +
  coord_sf(xlim=range(stand_coords[,'X']),
           ylim=range(stand_coords[,'Y'])) +
  theme_void() +
  theme(axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        plot.title=element_text(size=14, hjust=0.5),
        legend.position=c(.7,.15),
        legend.background=element_rect(fill='white',color='white'),
        legend.title=element_blank(),
        legend.text=element_text(size=14),
        panel.grid.major = element_line(color = 'transparent')) +
  geom_label(data=stand_centers,
             aes(x=X,y=Y,label=Name),size=6,fill='white',label.size=NA) +
  guides(fill=guide_legend(nrow=4,byrow=TRUE))

stand_map96 = time_stands %>% 
  mutate(Harvest = Harvest96) %>%
  ggplot() +
  ggtitle('After (1996-2011)') +
  geom_sf(aes(fill=Harvest),color='black') +
  scale_fill_manual(values=c('darkorange2','gold','gray'))+
  geom_sf(data=stand_bounds,fill='transparent',size=1.5,color='black') +
  coord_sf(xlim=range(stand_coords[,'X']),
           ylim=range(stand_coords[,'Y'])) +
  theme_void() +
  theme(axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        plot.title=element_text(size=14, hjust=0.5),
        legend.position='none',
        legend.title=element_blank(),
        legend.text=element_text(size=14),
        panel.grid.major = element_line(color = 'transparent')) +
  guides(fill=guide_legend(nrow=2,byrow=TRUE))

stand_map11 = time_stands %>% 
  mutate(Harvest11 = as.character(Harvest11),
         Harvest96 = as.character(Harvest96),
         Harvest = case_when(Harvest11 != 'No harvest' ~ Harvest11,
                             Harvest96 != 'No harvest' ~ '1996 Harvest',
                             TRUE ~ 'No harvest'),
         Harvest = factor(Harvest,levels=c('Regen','Thin',
                                           'No harvest','1996 Harvest'))) %>%
  ggplot() +
  ggtitle('After (2011-)') +
  geom_sf(aes(fill=Harvest),color='black') +
  scale_fill_manual(values=c('darkorange2','gold','gray','darkorange4'))+
  geom_sf(data=stand_bounds,fill='transparent',size=1.5,color='black') +
  coord_sf(xlim=range(stand_coords[,'X']),
           ylim=range(stand_coords[,'Y'])) +
  theme_void() +
  theme(axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        plot.title=element_text(size=14, hjust=0.5),
        legend.position='none',
        legend.title=element_blank(),
        legend.text=element_text(size=14),
        panel.grid.major = element_line(color = 'transparent')) +
  guides(fill=guide_legend(nrow=2,byrow=TRUE))

out2 = ggdraw() +
  draw_plot(stand_map92,0,0,0.33,1) +
  draw_plot(stand_map96,0.33,0,0.33,1) +
  draw_plot(stand_map11,0.66,0,0.33,1)

ggsave('fig_timeline.pdf',height=4.5)

out3 = ggdraw() +
  draw_plot(stand_map92,0,0,0.33,1)

ggsave('fig_timeline_part1.pdf',height=4.5)

out3 = ggdraw() +
  draw_plot(stand_map92,0,0,0.33,1) +
  draw_plot(stand_map96,0.33,0,0.33,1)

ggsave('fig_timeline_part2.pdf',height=4.5)

options(warn=0)
